/* valaobjectcreationexpression.c generated by valac, the Vala compiler
 * generated from valaobjectcreationexpression.vala, do not modify */

/* valaobjectcreationexpression.vala
 *
 * Copyright (C) 2006-2012  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <valagee.h>


#define VALA_TYPE_CODE_NODE (vala_code_node_get_type ())
#define VALA_CODE_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CODE_NODE, ValaCodeNode))
#define VALA_CODE_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CODE_NODE, ValaCodeNodeClass))
#define VALA_IS_CODE_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CODE_NODE))
#define VALA_IS_CODE_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CODE_NODE))
#define VALA_CODE_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CODE_NODE, ValaCodeNodeClass))

typedef struct _ValaCodeNode ValaCodeNode;
typedef struct _ValaCodeNodeClass ValaCodeNodeClass;
typedef struct _ValaCodeNodePrivate ValaCodeNodePrivate;

#define VALA_TYPE_CODE_VISITOR (vala_code_visitor_get_type ())
#define VALA_CODE_VISITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CODE_VISITOR, ValaCodeVisitor))
#define VALA_CODE_VISITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CODE_VISITOR, ValaCodeVisitorClass))
#define VALA_IS_CODE_VISITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CODE_VISITOR))
#define VALA_IS_CODE_VISITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CODE_VISITOR))
#define VALA_CODE_VISITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CODE_VISITOR, ValaCodeVisitorClass))

typedef struct _ValaCodeVisitor ValaCodeVisitor;
typedef struct _ValaCodeVisitorClass ValaCodeVisitorClass;

#define VALA_TYPE_CODE_CONTEXT (vala_code_context_get_type ())
#define VALA_CODE_CONTEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CODE_CONTEXT, ValaCodeContext))
#define VALA_CODE_CONTEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CODE_CONTEXT, ValaCodeContextClass))
#define VALA_IS_CODE_CONTEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CODE_CONTEXT))
#define VALA_IS_CODE_CONTEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CODE_CONTEXT))
#define VALA_CODE_CONTEXT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CODE_CONTEXT, ValaCodeContextClass))

typedef struct _ValaCodeContext ValaCodeContext;
typedef struct _ValaCodeContextClass ValaCodeContextClass;

#define VALA_TYPE_CODE_GENERATOR (vala_code_generator_get_type ())
#define VALA_CODE_GENERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CODE_GENERATOR, ValaCodeGenerator))
#define VALA_CODE_GENERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CODE_GENERATOR, ValaCodeGeneratorClass))
#define VALA_IS_CODE_GENERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CODE_GENERATOR))
#define VALA_IS_CODE_GENERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CODE_GENERATOR))
#define VALA_CODE_GENERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CODE_GENERATOR, ValaCodeGeneratorClass))

typedef struct _ValaCodeGenerator ValaCodeGenerator;
typedef struct _ValaCodeGeneratorClass ValaCodeGeneratorClass;

#define VALA_TYPE_DATA_TYPE (vala_data_type_get_type ())
#define VALA_DATA_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_DATA_TYPE, ValaDataType))
#define VALA_DATA_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_DATA_TYPE, ValaDataTypeClass))
#define VALA_IS_DATA_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_DATA_TYPE))
#define VALA_IS_DATA_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_DATA_TYPE))
#define VALA_DATA_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_DATA_TYPE, ValaDataTypeClass))

typedef struct _ValaDataType ValaDataType;
typedef struct _ValaDataTypeClass ValaDataTypeClass;

#define VALA_TYPE_EXPRESSION (vala_expression_get_type ())
#define VALA_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_EXPRESSION, ValaExpression))
#define VALA_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_EXPRESSION, ValaExpressionClass))
#define VALA_IS_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_EXPRESSION))
#define VALA_IS_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_EXPRESSION))
#define VALA_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_EXPRESSION, ValaExpressionClass))

typedef struct _ValaExpression ValaExpression;
typedef struct _ValaExpressionClass ValaExpressionClass;

#define VALA_TYPE_SYMBOL (vala_symbol_get_type ())
#define VALA_SYMBOL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SYMBOL, ValaSymbol))
#define VALA_SYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SYMBOL, ValaSymbolClass))
#define VALA_IS_SYMBOL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SYMBOL))
#define VALA_IS_SYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SYMBOL))
#define VALA_SYMBOL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SYMBOL, ValaSymbolClass))

typedef struct _ValaSymbol ValaSymbol;
typedef struct _ValaSymbolClass ValaSymbolClass;

#define VALA_TYPE_VARIABLE (vala_variable_get_type ())
#define VALA_VARIABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_VARIABLE, ValaVariable))
#define VALA_VARIABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_VARIABLE, ValaVariableClass))
#define VALA_IS_VARIABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_VARIABLE))
#define VALA_IS_VARIABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_VARIABLE))
#define VALA_VARIABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_VARIABLE, ValaVariableClass))

typedef struct _ValaVariable ValaVariable;
typedef struct _ValaVariableClass ValaVariableClass;

#define VALA_TYPE_ATTRIBUTE (vala_attribute_get_type ())
#define VALA_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ATTRIBUTE, ValaAttribute))
#define VALA_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ATTRIBUTE, ValaAttributeClass))
#define VALA_IS_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ATTRIBUTE))
#define VALA_IS_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ATTRIBUTE))
#define VALA_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ATTRIBUTE, ValaAttributeClass))

typedef struct _ValaAttribute ValaAttribute;
typedef struct _ValaAttributeClass ValaAttributeClass;
typedef struct _ValaExpressionPrivate ValaExpressionPrivate;

#define VALA_TYPE_OBJECT_CREATION_EXPRESSION (vala_object_creation_expression_get_type ())
#define VALA_OBJECT_CREATION_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_OBJECT_CREATION_EXPRESSION, ValaObjectCreationExpression))
#define VALA_OBJECT_CREATION_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_OBJECT_CREATION_EXPRESSION, ValaObjectCreationExpressionClass))
#define VALA_IS_OBJECT_CREATION_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_OBJECT_CREATION_EXPRESSION))
#define VALA_IS_OBJECT_CREATION_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_OBJECT_CREATION_EXPRESSION))
#define VALA_OBJECT_CREATION_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_OBJECT_CREATION_EXPRESSION, ValaObjectCreationExpressionClass))

typedef struct _ValaObjectCreationExpression ValaObjectCreationExpression;
typedef struct _ValaObjectCreationExpressionClass ValaObjectCreationExpressionClass;
typedef struct _ValaObjectCreationExpressionPrivate ValaObjectCreationExpressionPrivate;

#define VALA_TYPE_MEMBER_ACCESS (vala_member_access_get_type ())
#define VALA_MEMBER_ACCESS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_MEMBER_ACCESS, ValaMemberAccess))
#define VALA_MEMBER_ACCESS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_MEMBER_ACCESS, ValaMemberAccessClass))
#define VALA_IS_MEMBER_ACCESS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_MEMBER_ACCESS))
#define VALA_IS_MEMBER_ACCESS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_MEMBER_ACCESS))
#define VALA_MEMBER_ACCESS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_MEMBER_ACCESS, ValaMemberAccessClass))

typedef struct _ValaMemberAccess ValaMemberAccess;
typedef struct _ValaMemberAccessClass ValaMemberAccessClass;

#define VALA_TYPE_MEMBER_INITIALIZER (vala_member_initializer_get_type ())
#define VALA_MEMBER_INITIALIZER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_MEMBER_INITIALIZER, ValaMemberInitializer))
#define VALA_MEMBER_INITIALIZER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_MEMBER_INITIALIZER, ValaMemberInitializerClass))
#define VALA_IS_MEMBER_INITIALIZER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_MEMBER_INITIALIZER))
#define VALA_IS_MEMBER_INITIALIZER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_MEMBER_INITIALIZER))
#define VALA_MEMBER_INITIALIZER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_MEMBER_INITIALIZER, ValaMemberInitializerClass))

typedef struct _ValaMemberInitializer ValaMemberInitializer;
typedef struct _ValaMemberInitializerClass ValaMemberInitializerClass;
#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
#define _vala_iterable_unref0(var) ((var == NULL) ? NULL : (var = (vala_iterable_unref (var), NULL)))

#define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
#define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
#define VALA_SOURCE_REFERENCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReferenceClass))
#define VALA_IS_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SOURCE_REFERENCE))
#define VALA_IS_SOURCE_REFERENCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SOURCE_REFERENCE))
#define VALA_SOURCE_REFERENCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReferenceClass))

typedef struct _ValaSourceReference ValaSourceReference;
typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;

#define VALA_TYPE_TYPESYMBOL (vala_typesymbol_get_type ())
#define VALA_TYPESYMBOL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_TYPESYMBOL, ValaTypeSymbol))
#define VALA_TYPESYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_TYPESYMBOL, ValaTypeSymbolClass))
#define VALA_IS_TYPESYMBOL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_TYPESYMBOL))
#define VALA_IS_TYPESYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_TYPESYMBOL))
#define VALA_TYPESYMBOL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_TYPESYMBOL, ValaTypeSymbolClass))

typedef struct _ValaTypeSymbol ValaTypeSymbol;
typedef struct _ValaTypeSymbolClass ValaTypeSymbolClass;

#define VALA_TYPE_SUBROUTINE (vala_subroutine_get_type ())
#define VALA_SUBROUTINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SUBROUTINE, ValaSubroutine))
#define VALA_SUBROUTINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SUBROUTINE, ValaSubroutineClass))
#define VALA_IS_SUBROUTINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SUBROUTINE))
#define VALA_IS_SUBROUTINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SUBROUTINE))
#define VALA_SUBROUTINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SUBROUTINE, ValaSubroutineClass))

typedef struct _ValaSubroutine ValaSubroutine;
typedef struct _ValaSubroutineClass ValaSubroutineClass;

#define VALA_TYPE_METHOD (vala_method_get_type ())
#define VALA_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_METHOD, ValaMethod))
#define VALA_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_METHOD, ValaMethodClass))
#define VALA_IS_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_METHOD))
#define VALA_IS_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_METHOD))
#define VALA_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_METHOD, ValaMethodClass))

typedef struct _ValaMethod ValaMethod;
typedef struct _ValaMethodClass ValaMethodClass;

#define VALA_TYPE_CREATION_METHOD (vala_creation_method_get_type ())
#define VALA_CREATION_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CREATION_METHOD, ValaCreationMethod))
#define VALA_CREATION_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CREATION_METHOD, ValaCreationMethodClass))
#define VALA_IS_CREATION_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CREATION_METHOD))
#define VALA_IS_CREATION_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CREATION_METHOD))
#define VALA_CREATION_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CREATION_METHOD, ValaCreationMethodClass))

typedef struct _ValaCreationMethod ValaCreationMethod;
typedef struct _ValaCreationMethodClass ValaCreationMethodClass;
#define _g_free0(var) (var = (g_free (var), NULL))

#define VALA_TYPE_OBJECT_TYPE_SYMBOL (vala_object_type_symbol_get_type ())
#define VALA_OBJECT_TYPE_SYMBOL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_OBJECT_TYPE_SYMBOL, ValaObjectTypeSymbol))
#define VALA_OBJECT_TYPE_SYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_OBJECT_TYPE_SYMBOL, ValaObjectTypeSymbolClass))
#define VALA_IS_OBJECT_TYPE_SYMBOL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_OBJECT_TYPE_SYMBOL))
#define VALA_IS_OBJECT_TYPE_SYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_OBJECT_TYPE_SYMBOL))
#define VALA_OBJECT_TYPE_SYMBOL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_OBJECT_TYPE_SYMBOL, ValaObjectTypeSymbolClass))

typedef struct _ValaObjectTypeSymbol ValaObjectTypeSymbol;
typedef struct _ValaObjectTypeSymbolClass ValaObjectTypeSymbolClass;

#define VALA_TYPE_CLASS (vala_class_get_type ())
#define VALA_CLASS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CLASS, ValaClass))
#define VALA_CLASS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CLASS, ValaClassClass))
#define VALA_IS_CLASS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CLASS))
#define VALA_IS_CLASS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CLASS))
#define VALA_CLASS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CLASS, ValaClassClass))

typedef struct _ValaClass ValaClass;
typedef struct _ValaClassClass ValaClassClass;

#define VALA_TYPE_ERROR_DOMAIN (vala_error_domain_get_type ())
#define VALA_ERROR_DOMAIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ERROR_DOMAIN, ValaErrorDomain))
#define VALA_ERROR_DOMAIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ERROR_DOMAIN, ValaErrorDomainClass))
#define VALA_IS_ERROR_DOMAIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ERROR_DOMAIN))
#define VALA_IS_ERROR_DOMAIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ERROR_DOMAIN))
#define VALA_ERROR_DOMAIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ERROR_DOMAIN, ValaErrorDomainClass))

typedef struct _ValaErrorDomain ValaErrorDomain;
typedef struct _ValaErrorDomainClass ValaErrorDomainClass;

#define VALA_TYPE_ERROR_CODE (vala_error_code_get_type ())
#define VALA_ERROR_CODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ERROR_CODE, ValaErrorCode))
#define VALA_ERROR_CODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ERROR_CODE, ValaErrorCodeClass))
#define VALA_IS_ERROR_CODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ERROR_CODE))
#define VALA_IS_ERROR_CODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ERROR_CODE))
#define VALA_ERROR_CODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ERROR_CODE, ValaErrorCodeClass))

typedef struct _ValaErrorCode ValaErrorCode;
typedef struct _ValaErrorCodeClass ValaErrorCodeClass;

#define VALA_TYPE_REFERENCE_TYPE (vala_reference_type_get_type ())
#define VALA_REFERENCE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_REFERENCE_TYPE, ValaReferenceType))
#define VALA_REFERENCE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_REFERENCE_TYPE, ValaReferenceTypeClass))
#define VALA_IS_REFERENCE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_REFERENCE_TYPE))
#define VALA_IS_REFERENCE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_REFERENCE_TYPE))
#define VALA_REFERENCE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_REFERENCE_TYPE, ValaReferenceTypeClass))

typedef struct _ValaReferenceType ValaReferenceType;
typedef struct _ValaReferenceTypeClass ValaReferenceTypeClass;

#define VALA_TYPE_ERROR_TYPE (vala_error_type_get_type ())
#define VALA_ERROR_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ERROR_TYPE, ValaErrorType))
#define VALA_ERROR_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ERROR_TYPE, ValaErrorTypeClass))
#define VALA_IS_ERROR_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ERROR_TYPE))
#define VALA_IS_ERROR_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ERROR_TYPE))
#define VALA_ERROR_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ERROR_TYPE, ValaErrorTypeClass))

typedef struct _ValaErrorType ValaErrorType;
typedef struct _ValaErrorTypeClass ValaErrorTypeClass;

#define VALA_TYPE_OBJECT_TYPE (vala_object_type_get_type ())
#define VALA_OBJECT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_OBJECT_TYPE, ValaObjectType))
#define VALA_OBJECT_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_OBJECT_TYPE, ValaObjectTypeClass))
#define VALA_IS_OBJECT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_OBJECT_TYPE))
#define VALA_IS_OBJECT_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_OBJECT_TYPE))
#define VALA_OBJECT_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_OBJECT_TYPE, ValaObjectTypeClass))

typedef struct _ValaObjectType ValaObjectType;
typedef struct _ValaObjectTypeClass ValaObjectTypeClass;

#define VALA_TYPE_STRUCT (vala_struct_get_type ())
#define VALA_STRUCT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_STRUCT, ValaStruct))
#define VALA_STRUCT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_STRUCT, ValaStructClass))
#define VALA_IS_STRUCT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_STRUCT))
#define VALA_IS_STRUCT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_STRUCT))
#define VALA_STRUCT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_STRUCT, ValaStructClass))

typedef struct _ValaStruct ValaStruct;
typedef struct _ValaStructClass ValaStructClass;

#define VALA_TYPE_VALUE_TYPE (vala_value_type_get_type ())
#define VALA_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_VALUE_TYPE, ValaValueType))
#define VALA_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_VALUE_TYPE, ValaValueTypeClass))
#define VALA_IS_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_VALUE_TYPE))
#define VALA_IS_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_VALUE_TYPE))
#define VALA_VALUE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_VALUE_TYPE, ValaValueTypeClass))

typedef struct _ValaValueType ValaValueType;
typedef struct _ValaValueTypeClass ValaValueTypeClass;

#define VALA_TYPE_STRUCT_VALUE_TYPE (vala_struct_value_type_get_type ())
#define VALA_STRUCT_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueType))
#define VALA_STRUCT_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueTypeClass))
#define VALA_IS_STRUCT_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_STRUCT_VALUE_TYPE))
#define VALA_IS_STRUCT_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_STRUCT_VALUE_TYPE))
#define VALA_STRUCT_VALUE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueTypeClass))

typedef struct _ValaStructValueType ValaStructValueType;
typedef struct _ValaStructValueTypeClass ValaStructValueTypeClass;

#define VALA_TYPE_TYPEPARAMETER (vala_typeparameter_get_type ())
#define VALA_TYPEPARAMETER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_TYPEPARAMETER, ValaTypeParameter))
#define VALA_TYPEPARAMETER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_TYPEPARAMETER, ValaTypeParameterClass))
#define VALA_IS_TYPEPARAMETER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_TYPEPARAMETER))
#define VALA_IS_TYPEPARAMETER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_TYPEPARAMETER))
#define VALA_TYPEPARAMETER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_TYPEPARAMETER, ValaTypeParameterClass))

typedef struct _ValaTypeParameter ValaTypeParameter;
typedef struct _ValaTypeParameterClass ValaTypeParameterClass;

#define VALA_TYPE_SYMBOL_ACCESSIBILITY (vala_symbol_accessibility_get_type ())

#define VALA_TYPE_SEMANTIC_ANALYZER (vala_semantic_analyzer_get_type ())
#define VALA_SEMANTIC_ANALYZER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SEMANTIC_ANALYZER, ValaSemanticAnalyzer))
#define VALA_SEMANTIC_ANALYZER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SEMANTIC_ANALYZER, ValaSemanticAnalyzerClass))
#define VALA_IS_SEMANTIC_ANALYZER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SEMANTIC_ANALYZER))
#define VALA_IS_SEMANTIC_ANALYZER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SEMANTIC_ANALYZER))
#define VALA_SEMANTIC_ANALYZER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SEMANTIC_ANALYZER, ValaSemanticAnalyzerClass))

typedef struct _ValaSemanticAnalyzer ValaSemanticAnalyzer;
typedef struct _ValaSemanticAnalyzerClass ValaSemanticAnalyzerClass;

#define VALA_TYPE_PARAMETER (vala_parameter_get_type ())
#define VALA_PARAMETER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_PARAMETER, ValaParameter))
#define VALA_PARAMETER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_PARAMETER, ValaParameterClass))
#define VALA_IS_PARAMETER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_PARAMETER))
#define VALA_IS_PARAMETER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_PARAMETER))
#define VALA_PARAMETER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_PARAMETER, ValaParameterClass))

typedef struct _ValaParameter ValaParameter;
typedef struct _ValaParameterClass ValaParameterClass;

#define VALA_TYPE_METHOD_TYPE (vala_method_type_get_type ())
#define VALA_METHOD_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_METHOD_TYPE, ValaMethodType))
#define VALA_METHOD_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_METHOD_TYPE, ValaMethodTypeClass))
#define VALA_IS_METHOD_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_METHOD_TYPE))
#define VALA_IS_METHOD_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_METHOD_TYPE))
#define VALA_METHOD_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_METHOD_TYPE, ValaMethodTypeClass))

typedef struct _ValaMethodType ValaMethodType;
typedef struct _ValaMethodTypeClass ValaMethodTypeClass;
#define _vala_iterator_unref0(var) ((var == NULL) ? NULL : (var = (vala_iterator_unref (var), NULL)))
typedef struct _ValaCodeVisitorPrivate ValaCodeVisitorPrivate;

#define VALA_TYPE_SOURCE_FILE (vala_source_file_get_type ())
#define VALA_SOURCE_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_FILE, ValaSourceFile))
#define VALA_SOURCE_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SOURCE_FILE, ValaSourceFileClass))
#define VALA_IS_SOURCE_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SOURCE_FILE))
#define VALA_IS_SOURCE_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SOURCE_FILE))
#define VALA_SOURCE_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SOURCE_FILE, ValaSourceFileClass))

typedef struct _ValaSourceFile ValaSourceFile;
typedef struct _ValaSourceFileClass ValaSourceFileClass;

#define VALA_TYPE_NAMESPACE (vala_namespace_get_type ())
#define VALA_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_NAMESPACE, ValaNamespace))
#define VALA_NAMESPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_NAMESPACE, ValaNamespaceClass))
#define VALA_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_NAMESPACE))
#define VALA_IS_NAMESPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_NAMESPACE))
#define VALA_NAMESPACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_NAMESPACE, ValaNamespaceClass))

typedef struct _ValaNamespace ValaNamespace;
typedef struct _ValaNamespaceClass ValaNamespaceClass;

#define VALA_TYPE_INTERFACE (vala_interface_get_type ())
#define VALA_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_INTERFACE, ValaInterface))
#define VALA_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_INTERFACE, ValaInterfaceClass))
#define VALA_IS_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_INTERFACE))
#define VALA_IS_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_INTERFACE))
#define VALA_INTERFACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_INTERFACE, ValaInterfaceClass))

typedef struct _ValaInterface ValaInterface;
typedef struct _ValaInterfaceClass ValaInterfaceClass;

#define VALA_TYPE_ENUM (vala_enum_get_type ())
#define VALA_ENUM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ENUM, ValaEnum))
#define VALA_ENUM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ENUM, ValaEnumClass))
#define VALA_IS_ENUM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ENUM))
#define VALA_IS_ENUM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ENUM))
#define VALA_ENUM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ENUM, ValaEnumClass))

typedef struct _ValaEnum ValaEnum;
typedef struct _ValaEnumClass ValaEnumClass;

#define VALA_TYPE_CONSTANT (vala_constant_get_type ())
#define VALA_CONSTANT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CONSTANT, ValaConstant))
#define VALA_CONSTANT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CONSTANT, ValaConstantClass))
#define VALA_IS_CONSTANT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CONSTANT))
#define VALA_IS_CONSTANT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CONSTANT))
#define VALA_CONSTANT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CONSTANT, ValaConstantClass))

typedef struct _ValaConstant ValaConstant;
typedef struct _ValaConstantClass ValaConstantClass;

#define VALA_TYPE_ENUM_VALUE (vala_enum_value_get_type ())
#define VALA_ENUM_VALUE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ENUM_VALUE, ValaEnumValue))
#define VALA_ENUM_VALUE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ENUM_VALUE, ValaEnumValueClass))
#define VALA_IS_ENUM_VALUE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ENUM_VALUE))
#define VALA_IS_ENUM_VALUE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ENUM_VALUE))
#define VALA_ENUM_VALUE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ENUM_VALUE, ValaEnumValueClass))

typedef struct _ValaEnumValue ValaEnumValue;
typedef struct _ValaEnumValueClass ValaEnumValueClass;

#define VALA_TYPE_DELEGATE (vala_delegate_get_type ())
#define VALA_DELEGATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_DELEGATE, ValaDelegate))
#define VALA_DELEGATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_DELEGATE, ValaDelegateClass))
#define VALA_IS_DELEGATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_DELEGATE))
#define VALA_IS_DELEGATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_DELEGATE))
#define VALA_DELEGATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_DELEGATE, ValaDelegateClass))

typedef struct _ValaDelegate ValaDelegate;
typedef struct _ValaDelegateClass ValaDelegateClass;

#define VALA_TYPE_FIELD (vala_field_get_type ())
#define VALA_FIELD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_FIELD, ValaField))
#define VALA_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_FIELD, ValaFieldClass))
#define VALA_IS_FIELD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_FIELD))
#define VALA_IS_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_FIELD))
#define VALA_FIELD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_FIELD, ValaFieldClass))

typedef struct _ValaField ValaField;
typedef struct _ValaFieldClass ValaFieldClass;

#define VALA_TYPE_PROPERTY (vala_property_get_type ())
#define VALA_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_PROPERTY, ValaProperty))
#define VALA_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_PROPERTY, ValaPropertyClass))
#define VALA_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_PROPERTY))
#define VALA_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_PROPERTY))
#define VALA_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_PROPERTY, ValaPropertyClass))

typedef struct _ValaProperty ValaProperty;
typedef struct _ValaPropertyClass ValaPropertyClass;

#define VALA_TYPE_PROPERTY_ACCESSOR (vala_property_accessor_get_type ())
#define VALA_PROPERTY_ACCESSOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_PROPERTY_ACCESSOR, ValaPropertyAccessor))
#define VALA_PROPERTY_ACCESSOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_PROPERTY_ACCESSOR, ValaPropertyAccessorClass))
#define VALA_IS_PROPERTY_ACCESSOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_PROPERTY_ACCESSOR))
#define VALA_IS_PROPERTY_ACCESSOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_PROPERTY_ACCESSOR))
#define VALA_PROPERTY_ACCESSOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_PROPERTY_ACCESSOR, ValaPropertyAccessorClass))

typedef struct _ValaPropertyAccessor ValaPropertyAccessor;
typedef struct _ValaPropertyAccessorClass ValaPropertyAccessorClass;

#define VALA_TYPE_SIGNAL (vala_signal_get_type ())
#define VALA_SIGNAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SIGNAL, ValaSignal))
#define VALA_SIGNAL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SIGNAL, ValaSignalClass))
#define VALA_IS_SIGNAL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SIGNAL))
#define VALA_IS_SIGNAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SIGNAL))
#define VALA_SIGNAL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SIGNAL, ValaSignalClass))

typedef struct _ValaSignal ValaSignal;
typedef struct _ValaSignalClass ValaSignalClass;

#define VALA_TYPE_CONSTRUCTOR (vala_constructor_get_type ())
#define VALA_CONSTRUCTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CONSTRUCTOR, ValaConstructor))
#define VALA_CONSTRUCTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CONSTRUCTOR, ValaConstructorClass))
#define VALA_IS_CONSTRUCTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CONSTRUCTOR))
#define VALA_IS_CONSTRUCTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CONSTRUCTOR))
#define VALA_CONSTRUCTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CONSTRUCTOR, ValaConstructorClass))

typedef struct _ValaConstructor ValaConstructor;
typedef struct _ValaConstructorClass ValaConstructorClass;

#define VALA_TYPE_DESTRUCTOR (vala_destructor_get_type ())
#define VALA_DESTRUCTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_DESTRUCTOR, ValaDestructor))
#define VALA_DESTRUCTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_DESTRUCTOR, ValaDestructorClass))
#define VALA_IS_DESTRUCTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_DESTRUCTOR))
#define VALA_IS_DESTRUCTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_DESTRUCTOR))
#define VALA_DESTRUCTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_DESTRUCTOR, ValaDestructorClass))

typedef struct _ValaDestructor ValaDestructor;
typedef struct _ValaDestructorClass ValaDestructorClass;

#define VALA_TYPE_USING_DIRECTIVE (vala_using_directive_get_type ())
#define VALA_USING_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_USING_DIRECTIVE, ValaUsingDirective))
#define VALA_USING_DIRECTIVE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_USING_DIRECTIVE, ValaUsingDirectiveClass))
#define VALA_IS_USING_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_USING_DIRECTIVE))
#define VALA_IS_USING_DIRECTIVE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_USING_DIRECTIVE))
#define VALA_USING_DIRECTIVE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_USING_DIRECTIVE, ValaUsingDirectiveClass))

typedef struct _ValaUsingDirective ValaUsingDirective;
typedef struct _ValaUsingDirectiveClass ValaUsingDirectiveClass;

#define VALA_TYPE_BLOCK (vala_block_get_type ())
#define VALA_BLOCK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_BLOCK, ValaBlock))
#define VALA_BLOCK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_BLOCK, ValaBlockClass))
#define VALA_IS_BLOCK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_BLOCK))
#define VALA_IS_BLOCK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_BLOCK))
#define VALA_BLOCK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_BLOCK, ValaBlockClass))

typedef struct _ValaBlock ValaBlock;
typedef struct _ValaBlockClass ValaBlockClass;

#define VALA_TYPE_EMPTY_STATEMENT (vala_empty_statement_get_type ())
#define VALA_EMPTY_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_EMPTY_STATEMENT, ValaEmptyStatement))
#define VALA_EMPTY_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_EMPTY_STATEMENT, ValaEmptyStatementClass))
#define VALA_IS_EMPTY_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_EMPTY_STATEMENT))
#define VALA_IS_EMPTY_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_EMPTY_STATEMENT))
#define VALA_EMPTY_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_EMPTY_STATEMENT, ValaEmptyStatementClass))

typedef struct _ValaEmptyStatement ValaEmptyStatement;
typedef struct _ValaEmptyStatementClass ValaEmptyStatementClass;

#define VALA_TYPE_DECLARATION_STATEMENT (vala_declaration_statement_get_type ())
#define VALA_DECLARATION_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_DECLARATION_STATEMENT, ValaDeclarationStatement))
#define VALA_DECLARATION_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_DECLARATION_STATEMENT, ValaDeclarationStatementClass))
#define VALA_IS_DECLARATION_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_DECLARATION_STATEMENT))
#define VALA_IS_DECLARATION_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_DECLARATION_STATEMENT))
#define VALA_DECLARATION_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_DECLARATION_STATEMENT, ValaDeclarationStatementClass))

typedef struct _ValaDeclarationStatement ValaDeclarationStatement;
typedef struct _ValaDeclarationStatementClass ValaDeclarationStatementClass;

#define VALA_TYPE_LOCAL_VARIABLE (vala_local_variable_get_type ())
#define VALA_LOCAL_VARIABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LOCAL_VARIABLE, ValaLocalVariable))
#define VALA_LOCAL_VARIABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_LOCAL_VARIABLE, ValaLocalVariableClass))
#define VALA_IS_LOCAL_VARIABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_LOCAL_VARIABLE))
#define VALA_IS_LOCAL_VARIABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_LOCAL_VARIABLE))
#define VALA_LOCAL_VARIABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_LOCAL_VARIABLE, ValaLocalVariableClass))

typedef struct _ValaLocalVariable ValaLocalVariable;
typedef struct _ValaLocalVariableClass ValaLocalVariableClass;

#define VALA_TYPE_INITIALIZER_LIST (vala_initializer_list_get_type ())
#define VALA_INITIALIZER_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_INITIALIZER_LIST, ValaInitializerList))
#define VALA_INITIALIZER_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_INITIALIZER_LIST, ValaInitializerListClass))
#define VALA_IS_INITIALIZER_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_INITIALIZER_LIST))
#define VALA_IS_INITIALIZER_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_INITIALIZER_LIST))
#define VALA_INITIALIZER_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_INITIALIZER_LIST, ValaInitializerListClass))

typedef struct _ValaInitializerList ValaInitializerList;
typedef struct _ValaInitializerListClass ValaInitializerListClass;

#define VALA_TYPE_EXPRESSION_STATEMENT (vala_expression_statement_get_type ())
#define VALA_EXPRESSION_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_EXPRESSION_STATEMENT, ValaExpressionStatement))
#define VALA_EXPRESSION_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_EXPRESSION_STATEMENT, ValaExpressionStatementClass))
#define VALA_IS_EXPRESSION_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_EXPRESSION_STATEMENT))
#define VALA_IS_EXPRESSION_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_EXPRESSION_STATEMENT))
#define VALA_EXPRESSION_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_EXPRESSION_STATEMENT, ValaExpressionStatementClass))

typedef struct _ValaExpressionStatement ValaExpressionStatement;
typedef struct _ValaExpressionStatementClass ValaExpressionStatementClass;

#define VALA_TYPE_IF_STATEMENT (vala_if_statement_get_type ())
#define VALA_IF_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_IF_STATEMENT, ValaIfStatement))
#define VALA_IF_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_IF_STATEMENT, ValaIfStatementClass))
#define VALA_IS_IF_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_IF_STATEMENT))
#define VALA_IS_IF_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_IF_STATEMENT))
#define VALA_IF_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_IF_STATEMENT, ValaIfStatementClass))

typedef struct _ValaIfStatement ValaIfStatement;
typedef struct _ValaIfStatementClass ValaIfStatementClass;

#define VALA_TYPE_SWITCH_STATEMENT (vala_switch_statement_get_type ())
#define VALA_SWITCH_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SWITCH_STATEMENT, ValaSwitchStatement))
#define VALA_SWITCH_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SWITCH_STATEMENT, ValaSwitchStatementClass))
#define VALA_IS_SWITCH_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SWITCH_STATEMENT))
#define VALA_IS_SWITCH_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SWITCH_STATEMENT))
#define VALA_SWITCH_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SWITCH_STATEMENT, ValaSwitchStatementClass))

typedef struct _ValaSwitchStatement ValaSwitchStatement;
typedef struct _ValaSwitchStatementClass ValaSwitchStatementClass;

#define VALA_TYPE_SWITCH_SECTION (vala_switch_section_get_type ())
#define VALA_SWITCH_SECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SWITCH_SECTION, ValaSwitchSection))
#define VALA_SWITCH_SECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SWITCH_SECTION, ValaSwitchSectionClass))
#define VALA_IS_SWITCH_SECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SWITCH_SECTION))
#define VALA_IS_SWITCH_SECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SWITCH_SECTION))
#define VALA_SWITCH_SECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SWITCH_SECTION, ValaSwitchSectionClass))

typedef struct _ValaSwitchSection ValaSwitchSection;
typedef struct _ValaSwitchSectionClass ValaSwitchSectionClass;

#define VALA_TYPE_SWITCH_LABEL (vala_switch_label_get_type ())
#define VALA_SWITCH_LABEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SWITCH_LABEL, ValaSwitchLabel))
#define VALA_SWITCH_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SWITCH_LABEL, ValaSwitchLabelClass))
#define VALA_IS_SWITCH_LABEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SWITCH_LABEL))
#define VALA_IS_SWITCH_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SWITCH_LABEL))
#define VALA_SWITCH_LABEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SWITCH_LABEL, ValaSwitchLabelClass))

typedef struct _ValaSwitchLabel ValaSwitchLabel;
typedef struct _ValaSwitchLabelClass ValaSwitchLabelClass;

#define VALA_TYPE_LOOP (vala_loop_get_type ())
#define VALA_LOOP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LOOP, ValaLoop))
#define VALA_LOOP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_LOOP, ValaLoopClass))
#define VALA_IS_LOOP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_LOOP))
#define VALA_IS_LOOP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_LOOP))
#define VALA_LOOP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_LOOP, ValaLoopClass))

typedef struct _ValaLoop ValaLoop;
typedef struct _ValaLoopClass ValaLoopClass;

#define VALA_TYPE_WHILE_STATEMENT (vala_while_statement_get_type ())
#define VALA_WHILE_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatement))
#define VALA_WHILE_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatementClass))
#define VALA_IS_WHILE_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_WHILE_STATEMENT))
#define VALA_IS_WHILE_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_WHILE_STATEMENT))
#define VALA_WHILE_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatementClass))

typedef struct _ValaWhileStatement ValaWhileStatement;
typedef struct _ValaWhileStatementClass ValaWhileStatementClass;

#define VALA_TYPE_DO_STATEMENT (vala_do_statement_get_type ())
#define VALA_DO_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_DO_STATEMENT, ValaDoStatement))
#define VALA_DO_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_DO_STATEMENT, ValaDoStatementClass))
#define VALA_IS_DO_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_DO_STATEMENT))
#define VALA_IS_DO_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_DO_STATEMENT))
#define VALA_DO_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_DO_STATEMENT, ValaDoStatementClass))

typedef struct _ValaDoStatement ValaDoStatement;
typedef struct _ValaDoStatementClass ValaDoStatementClass;

#define VALA_TYPE_FOR_STATEMENT (vala_for_statement_get_type ())
#define VALA_FOR_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_FOR_STATEMENT, ValaForStatement))
#define VALA_FOR_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_FOR_STATEMENT, ValaForStatementClass))
#define VALA_IS_FOR_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_FOR_STATEMENT))
#define VALA_IS_FOR_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_FOR_STATEMENT))
#define VALA_FOR_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_FOR_STATEMENT, ValaForStatementClass))

typedef struct _ValaForStatement ValaForStatement;
typedef struct _ValaForStatementClass ValaForStatementClass;

#define VALA_TYPE_FOREACH_STATEMENT (vala_foreach_statement_get_type ())
#define VALA_FOREACH_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_FOREACH_STATEMENT, ValaForeachStatement))
#define VALA_FOREACH_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_FOREACH_STATEMENT, ValaForeachStatementClass))
#define VALA_IS_FOREACH_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_FOREACH_STATEMENT))
#define VALA_IS_FOREACH_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_FOREACH_STATEMENT))
#define VALA_FOREACH_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_FOREACH_STATEMENT, ValaForeachStatementClass))

typedef struct _ValaForeachStatement ValaForeachStatement;
typedef struct _ValaForeachStatementClass ValaForeachStatementClass;

#define VALA_TYPE_BREAK_STATEMENT (vala_break_statement_get_type ())
#define VALA_BREAK_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_BREAK_STATEMENT, ValaBreakStatement))
#define VALA_BREAK_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_BREAK_STATEMENT, ValaBreakStatementClass))
#define VALA_IS_BREAK_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_BREAK_STATEMENT))
#define VALA_IS_BREAK_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_BREAK_STATEMENT))
#define VALA_BREAK_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_BREAK_STATEMENT, ValaBreakStatementClass))

typedef struct _ValaBreakStatement ValaBreakStatement;
typedef struct _ValaBreakStatementClass ValaBreakStatementClass;

#define VALA_TYPE_CONTINUE_STATEMENT (vala_continue_statement_get_type ())
#define VALA_CONTINUE_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CONTINUE_STATEMENT, ValaContinueStatement))
#define VALA_CONTINUE_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CONTINUE_STATEMENT, ValaContinueStatementClass))
#define VALA_IS_CONTINUE_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CONTINUE_STATEMENT))
#define VALA_IS_CONTINUE_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CONTINUE_STATEMENT))
#define VALA_CONTINUE_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CONTINUE_STATEMENT, ValaContinueStatementClass))

typedef struct _ValaContinueStatement ValaContinueStatement;
typedef struct _ValaContinueStatementClass ValaContinueStatementClass;

#define VALA_TYPE_RETURN_STATEMENT (vala_return_statement_get_type ())
#define VALA_RETURN_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_RETURN_STATEMENT, ValaReturnStatement))
#define VALA_RETURN_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_RETURN_STATEMENT, ValaReturnStatementClass))
#define VALA_IS_RETURN_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_RETURN_STATEMENT))
#define VALA_IS_RETURN_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_RETURN_STATEMENT))
#define VALA_RETURN_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_RETURN_STATEMENT, ValaReturnStatementClass))

typedef struct _ValaReturnStatement ValaReturnStatement;
typedef struct _ValaReturnStatementClass ValaReturnStatementClass;

#define VALA_TYPE_YIELD_STATEMENT (vala_yield_statement_get_type ())
#define VALA_YIELD_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_YIELD_STATEMENT, ValaYieldStatement))
#define VALA_YIELD_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_YIELD_STATEMENT, ValaYieldStatementClass))
#define VALA_IS_YIELD_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_YIELD_STATEMENT))
#define VALA_IS_YIELD_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_YIELD_STATEMENT))
#define VALA_YIELD_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_YIELD_STATEMENT, ValaYieldStatementClass))

typedef struct _ValaYieldStatement ValaYieldStatement;
typedef struct _ValaYieldStatementClass ValaYieldStatementClass;

#define VALA_TYPE_THROW_STATEMENT (vala_throw_statement_get_type ())
#define VALA_THROW_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_THROW_STATEMENT, ValaThrowStatement))
#define VALA_THROW_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_THROW_STATEMENT, ValaThrowStatementClass))
#define VALA_IS_THROW_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_THROW_STATEMENT))
#define VALA_IS_THROW_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_THROW_STATEMENT))
#define VALA_THROW_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_THROW_STATEMENT, ValaThrowStatementClass))

typedef struct _ValaThrowStatement ValaThrowStatement;
typedef struct _ValaThrowStatementClass ValaThrowStatementClass;

#define VALA_TYPE_TRY_STATEMENT (vala_try_statement_get_type ())
#define VALA_TRY_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_TRY_STATEMENT, ValaTryStatement))
#define VALA_TRY_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_TRY_STATEMENT, ValaTryStatementClass))
#define VALA_IS_TRY_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_TRY_STATEMENT))
#define VALA_IS_TRY_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_TRY_STATEMENT))
#define VALA_TRY_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_TRY_STATEMENT, ValaTryStatementClass))

typedef struct _ValaTryStatement ValaTryStatement;
typedef struct _ValaTryStatementClass ValaTryStatementClass;

#define VALA_TYPE_CATCH_CLAUSE (vala_catch_clause_get_type ())
#define VALA_CATCH_CLAUSE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CATCH_CLAUSE, ValaCatchClause))
#define VALA_CATCH_CLAUSE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CATCH_CLAUSE, ValaCatchClauseClass))
#define VALA_IS_CATCH_CLAUSE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CATCH_CLAUSE))
#define VALA_IS_CATCH_CLAUSE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CATCH_CLAUSE))
#define VALA_CATCH_CLAUSE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CATCH_CLAUSE, ValaCatchClauseClass))

typedef struct _ValaCatchClause ValaCatchClause;
typedef struct _ValaCatchClauseClass ValaCatchClauseClass;

#define VALA_TYPE_LOCK_STATEMENT (vala_lock_statement_get_type ())
#define VALA_LOCK_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LOCK_STATEMENT, ValaLockStatement))
#define VALA_LOCK_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_LOCK_STATEMENT, ValaLockStatementClass))
#define VALA_IS_LOCK_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_LOCK_STATEMENT))
#define VALA_IS_LOCK_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_LOCK_STATEMENT))
#define VALA_LOCK_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_LOCK_STATEMENT, ValaLockStatementClass))

typedef struct _ValaLockStatement ValaLockStatement;
typedef struct _ValaLockStatementClass ValaLockStatementClass;

#define VALA_TYPE_UNLOCK_STATEMENT (vala_unlock_statement_get_type ())
#define VALA_UNLOCK_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_UNLOCK_STATEMENT, ValaUnlockStatement))
#define VALA_UNLOCK_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_UNLOCK_STATEMENT, ValaUnlockStatementClass))
#define VALA_IS_UNLOCK_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_UNLOCK_STATEMENT))
#define VALA_IS_UNLOCK_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_UNLOCK_STATEMENT))
#define VALA_UNLOCK_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_UNLOCK_STATEMENT, ValaUnlockStatementClass))

typedef struct _ValaUnlockStatement ValaUnlockStatement;
typedef struct _ValaUnlockStatementClass ValaUnlockStatementClass;

#define VALA_TYPE_DELETE_STATEMENT (vala_delete_statement_get_type ())
#define VALA_DELETE_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_DELETE_STATEMENT, ValaDeleteStatement))
#define VALA_DELETE_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_DELETE_STATEMENT, ValaDeleteStatementClass))
#define VALA_IS_DELETE_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_DELETE_STATEMENT))
#define VALA_IS_DELETE_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_DELETE_STATEMENT))
#define VALA_DELETE_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_DELETE_STATEMENT, ValaDeleteStatementClass))

typedef struct _ValaDeleteStatement ValaDeleteStatement;
typedef struct _ValaDeleteStatementClass ValaDeleteStatementClass;

#define VALA_TYPE_ARRAY_CREATION_EXPRESSION (vala_array_creation_expression_get_type ())
#define VALA_ARRAY_CREATION_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ARRAY_CREATION_EXPRESSION, ValaArrayCreationExpression))
#define VALA_ARRAY_CREATION_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ARRAY_CREATION_EXPRESSION, ValaArrayCreationExpressionClass))
#define VALA_IS_ARRAY_CREATION_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ARRAY_CREATION_EXPRESSION))
#define VALA_IS_ARRAY_CREATION_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ARRAY_CREATION_EXPRESSION))
#define VALA_ARRAY_CREATION_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ARRAY_CREATION_EXPRESSION, ValaArrayCreationExpressionClass))

typedef struct _ValaArrayCreationExpression ValaArrayCreationExpression;
typedef struct _ValaArrayCreationExpressionClass ValaArrayCreationExpressionClass;

#define VALA_TYPE_LITERAL (vala_literal_get_type ())
#define VALA_LITERAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LITERAL, ValaLiteral))
#define VALA_LITERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_LITERAL, ValaLiteralClass))
#define VALA_IS_LITERAL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_LITERAL))
#define VALA_IS_LITERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_LITERAL))
#define VALA_LITERAL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_LITERAL, ValaLiteralClass))

typedef struct _ValaLiteral ValaLiteral;
typedef struct _ValaLiteralClass ValaLiteralClass;

#define VALA_TYPE_BOOLEAN_LITERAL (vala_boolean_literal_get_type ())
#define VALA_BOOLEAN_LITERAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_BOOLEAN_LITERAL, ValaBooleanLiteral))
#define VALA_BOOLEAN_LITERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_BOOLEAN_LITERAL, ValaBooleanLiteralClass))
#define VALA_IS_BOOLEAN_LITERAL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_BOOLEAN_LITERAL))
#define VALA_IS_BOOLEAN_LITERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_BOOLEAN_LITERAL))
#define VALA_BOOLEAN_LITERAL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_BOOLEAN_LITERAL, ValaBooleanLiteralClass))

typedef struct _ValaBooleanLiteral ValaBooleanLiteral;
typedef struct _ValaBooleanLiteralClass ValaBooleanLiteralClass;

#define VALA_TYPE_CHARACTER_LITERAL (vala_character_literal_get_type ())
#define VALA_CHARACTER_LITERAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CHARACTER_LITERAL, ValaCharacterLiteral))
#define VALA_CHARACTER_LITERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CHARACTER_LITERAL, ValaCharacterLiteralClass))
#define VALA_IS_CHARACTER_LITERAL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CHARACTER_LITERAL))
#define VALA_IS_CHARACTER_LITERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CHARACTER_LITERAL))
#define VALA_CHARACTER_LITERAL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CHARACTER_LITERAL, ValaCharacterLiteralClass))

typedef struct _ValaCharacterLiteral ValaCharacterLiteral;
typedef struct _ValaCharacterLiteralClass ValaCharacterLiteralClass;

#define VALA_TYPE_INTEGER_LITERAL (vala_integer_literal_get_type ())
#define VALA_INTEGER_LITERAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_INTEGER_LITERAL, ValaIntegerLiteral))
#define VALA_INTEGER_LITERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_INTEGER_LITERAL, ValaIntegerLiteralClass))
#define VALA_IS_INTEGER_LITERAL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_INTEGER_LITERAL))
#define VALA_IS_INTEGER_LITERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_INTEGER_LITERAL))
#define VALA_INTEGER_LITERAL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_INTEGER_LITERAL, ValaIntegerLiteralClass))

typedef struct _ValaIntegerLiteral ValaIntegerLiteral;
typedef struct _ValaIntegerLiteralClass ValaIntegerLiteralClass;

#define VALA_TYPE_REAL_LITERAL (vala_real_literal_get_type ())
#define VALA_REAL_LITERAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_REAL_LITERAL, ValaRealLiteral))
#define VALA_REAL_LITERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_REAL_LITERAL, ValaRealLiteralClass))
#define VALA_IS_REAL_LITERAL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_REAL_LITERAL))
#define VALA_IS_REAL_LITERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_REAL_LITERAL))
#define VALA_REAL_LITERAL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_REAL_LITERAL, ValaRealLiteralClass))

typedef struct _ValaRealLiteral ValaRealLiteral;
typedef struct _ValaRealLiteralClass ValaRealLiteralClass;

#define VALA_TYPE_REGEX_LITERAL (vala_regex_literal_get_type ())
#define VALA_REGEX_LITERAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_REGEX_LITERAL, ValaRegexLiteral))
#define VALA_REGEX_LITERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_REGEX_LITERAL, ValaRegexLiteralClass))
#define VALA_IS_REGEX_LITERAL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_REGEX_LITERAL))
#define VALA_IS_REGEX_LITERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_REGEX_LITERAL))
#define VALA_REGEX_LITERAL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_REGEX_LITERAL, ValaRegexLiteralClass))

typedef struct _ValaRegexLiteral ValaRegexLiteral;
typedef struct _ValaRegexLiteralClass ValaRegexLiteralClass;

#define VALA_TYPE_STRING_LITERAL (vala_string_literal_get_type ())
#define VALA_STRING_LITERAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_STRING_LITERAL, ValaStringLiteral))
#define VALA_STRING_LITERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_STRING_LITERAL, ValaStringLiteralClass))
#define VALA_IS_STRING_LITERAL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_STRING_LITERAL))
#define VALA_IS_STRING_LITERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_STRING_LITERAL))
#define VALA_STRING_LITERAL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_STRING_LITERAL, ValaStringLiteralClass))

typedef struct _ValaStringLiteral ValaStringLiteral;
typedef struct _ValaStringLiteralClass ValaStringLiteralClass;

#define VALA_TYPE_TEMPLATE (vala_template_get_type ())
#define VALA_TEMPLATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_TEMPLATE, ValaTemplate))
#define VALA_TEMPLATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_TEMPLATE, ValaTemplateClass))
#define VALA_IS_TEMPLATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_TEMPLATE))
#define VALA_IS_TEMPLATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_TEMPLATE))
#define VALA_TEMPLATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_TEMPLATE, ValaTemplateClass))

typedef struct _ValaTemplate ValaTemplate;
typedef struct _ValaTemplateClass ValaTemplateClass;

#define VALA_TYPE_TUPLE (vala_tuple_get_type ())
#define VALA_TUPLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_TUPLE, ValaTuple))
#define VALA_TUPLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_TUPLE, ValaTupleClass))
#define VALA_IS_TUPLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_TUPLE))
#define VALA_IS_TUPLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_TUPLE))
#define VALA_TUPLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_TUPLE, ValaTupleClass))

typedef struct _ValaTuple ValaTuple;
typedef struct _ValaTupleClass ValaTupleClass;

#define VALA_TYPE_NULL_LITERAL (vala_null_literal_get_type ())
#define VALA_NULL_LITERAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_NULL_LITERAL, ValaNullLiteral))
#define VALA_NULL_LITERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_NULL_LITERAL, ValaNullLiteralClass))
#define VALA_IS_NULL_LITERAL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_NULL_LITERAL))
#define VALA_IS_NULL_LITERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_NULL_LITERAL))
#define VALA_NULL_LITERAL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_NULL_LITERAL, ValaNullLiteralClass))

typedef struct _ValaNullLiteral ValaNullLiteral;
typedef struct _ValaNullLiteralClass ValaNullLiteralClass;

#define VALA_TYPE_METHOD_CALL (vala_method_call_get_type ())
#define VALA_METHOD_CALL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_METHOD_CALL, ValaMethodCall))
#define VALA_METHOD_CALL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_METHOD_CALL, ValaMethodCallClass))
#define VALA_IS_METHOD_CALL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_METHOD_CALL))
#define VALA_IS_METHOD_CALL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_METHOD_CALL))
#define VALA_METHOD_CALL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_METHOD_CALL, ValaMethodCallClass))

typedef struct _ValaMethodCall ValaMethodCall;
typedef struct _ValaMethodCallClass ValaMethodCallClass;

#define VALA_TYPE_ELEMENT_ACCESS (vala_element_access_get_type ())
#define VALA_ELEMENT_ACCESS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ELEMENT_ACCESS, ValaElementAccess))
#define VALA_ELEMENT_ACCESS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ELEMENT_ACCESS, ValaElementAccessClass))
#define VALA_IS_ELEMENT_ACCESS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ELEMENT_ACCESS))
#define VALA_IS_ELEMENT_ACCESS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ELEMENT_ACCESS))
#define VALA_ELEMENT_ACCESS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ELEMENT_ACCESS, ValaElementAccessClass))

typedef struct _ValaElementAccess ValaElementAccess;
typedef struct _ValaElementAccessClass ValaElementAccessClass;

#define VALA_TYPE_SLICE_EXPRESSION (vala_slice_expression_get_type ())
#define VALA_SLICE_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SLICE_EXPRESSION, ValaSliceExpression))
#define VALA_SLICE_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SLICE_EXPRESSION, ValaSliceExpressionClass))
#define VALA_IS_SLICE_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SLICE_EXPRESSION))
#define VALA_IS_SLICE_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SLICE_EXPRESSION))
#define VALA_SLICE_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SLICE_EXPRESSION, ValaSliceExpressionClass))

typedef struct _ValaSliceExpression ValaSliceExpression;
typedef struct _ValaSliceExpressionClass ValaSliceExpressionClass;

#define VALA_TYPE_BASE_ACCESS (vala_base_access_get_type ())
#define VALA_BASE_ACCESS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_BASE_ACCESS, ValaBaseAccess))
#define VALA_BASE_ACCESS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_BASE_ACCESS, ValaBaseAccessClass))
#define VALA_IS_BASE_ACCESS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_BASE_ACCESS))
#define VALA_IS_BASE_ACCESS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_BASE_ACCESS))
#define VALA_BASE_ACCESS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_BASE_ACCESS, ValaBaseAccessClass))

typedef struct _ValaBaseAccess ValaBaseAccess;
typedef struct _ValaBaseAccessClass ValaBaseAccessClass;

#define VALA_TYPE_POSTFIX_EXPRESSION (vala_postfix_expression_get_type ())
#define VALA_POSTFIX_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_POSTFIX_EXPRESSION, ValaPostfixExpression))
#define VALA_POSTFIX_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_POSTFIX_EXPRESSION, ValaPostfixExpressionClass))
#define VALA_IS_POSTFIX_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_POSTFIX_EXPRESSION))
#define VALA_IS_POSTFIX_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_POSTFIX_EXPRESSION))
#define VALA_POSTFIX_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_POSTFIX_EXPRESSION, ValaPostfixExpressionClass))

typedef struct _ValaPostfixExpression ValaPostfixExpression;
typedef struct _ValaPostfixExpressionClass ValaPostfixExpressionClass;

#define VALA_TYPE_SIZEOF_EXPRESSION (vala_sizeof_expression_get_type ())
#define VALA_SIZEOF_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SIZEOF_EXPRESSION, ValaSizeofExpression))
#define VALA_SIZEOF_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SIZEOF_EXPRESSION, ValaSizeofExpressionClass))
#define VALA_IS_SIZEOF_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SIZEOF_EXPRESSION))
#define VALA_IS_SIZEOF_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SIZEOF_EXPRESSION))
#define VALA_SIZEOF_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SIZEOF_EXPRESSION, ValaSizeofExpressionClass))

typedef struct _ValaSizeofExpression ValaSizeofExpression;
typedef struct _ValaSizeofExpressionClass ValaSizeofExpressionClass;

#define VALA_TYPE_TYPEOF_EXPRESSION (vala_typeof_expression_get_type ())
#define VALA_TYPEOF_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_TYPEOF_EXPRESSION, ValaTypeofExpression))
#define VALA_TYPEOF_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_TYPEOF_EXPRESSION, ValaTypeofExpressionClass))
#define VALA_IS_TYPEOF_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_TYPEOF_EXPRESSION))
#define VALA_IS_TYPEOF_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_TYPEOF_EXPRESSION))
#define VALA_TYPEOF_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_TYPEOF_EXPRESSION, ValaTypeofExpressionClass))

typedef struct _ValaTypeofExpression ValaTypeofExpression;
typedef struct _ValaTypeofExpressionClass ValaTypeofExpressionClass;

#define VALA_TYPE_UNARY_EXPRESSION (vala_unary_expression_get_type ())
#define VALA_UNARY_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_UNARY_EXPRESSION, ValaUnaryExpression))
#define VALA_UNARY_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_UNARY_EXPRESSION, ValaUnaryExpressionClass))
#define VALA_IS_UNARY_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_UNARY_EXPRESSION))
#define VALA_IS_UNARY_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_UNARY_EXPRESSION))
#define VALA_UNARY_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_UNARY_EXPRESSION, ValaUnaryExpressionClass))

typedef struct _ValaUnaryExpression ValaUnaryExpression;
typedef struct _ValaUnaryExpressionClass ValaUnaryExpressionClass;

#define VALA_TYPE_CAST_EXPRESSION (vala_cast_expression_get_type ())
#define VALA_CAST_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CAST_EXPRESSION, ValaCastExpression))
#define VALA_CAST_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CAST_EXPRESSION, ValaCastExpressionClass))
#define VALA_IS_CAST_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CAST_EXPRESSION))
#define VALA_IS_CAST_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CAST_EXPRESSION))
#define VALA_CAST_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CAST_EXPRESSION, ValaCastExpressionClass))

typedef struct _ValaCastExpression ValaCastExpression;
typedef struct _ValaCastExpressionClass ValaCastExpressionClass;

#define VALA_TYPE_NAMED_ARGUMENT (vala_named_argument_get_type ())
#define VALA_NAMED_ARGUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_NAMED_ARGUMENT, ValaNamedArgument))
#define VALA_NAMED_ARGUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_NAMED_ARGUMENT, ValaNamedArgumentClass))
#define VALA_IS_NAMED_ARGUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_NAMED_ARGUMENT))
#define VALA_IS_NAMED_ARGUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_NAMED_ARGUMENT))
#define VALA_NAMED_ARGUMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_NAMED_ARGUMENT, ValaNamedArgumentClass))

typedef struct _ValaNamedArgument ValaNamedArgument;
typedef struct _ValaNamedArgumentClass ValaNamedArgumentClass;

#define VALA_TYPE_POINTER_INDIRECTION (vala_pointer_indirection_get_type ())
#define VALA_POINTER_INDIRECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_POINTER_INDIRECTION, ValaPointerIndirection))
#define VALA_POINTER_INDIRECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_POINTER_INDIRECTION, ValaPointerIndirectionClass))
#define VALA_IS_POINTER_INDIRECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_POINTER_INDIRECTION))
#define VALA_IS_POINTER_INDIRECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_POINTER_INDIRECTION))
#define VALA_POINTER_INDIRECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_POINTER_INDIRECTION, ValaPointerIndirectionClass))

typedef struct _ValaPointerIndirection ValaPointerIndirection;
typedef struct _ValaPointerIndirectionClass ValaPointerIndirectionClass;

#define VALA_TYPE_ADDRESSOF_EXPRESSION (vala_addressof_expression_get_type ())
#define VALA_ADDRESSOF_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ADDRESSOF_EXPRESSION, ValaAddressofExpression))
#define VALA_ADDRESSOF_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ADDRESSOF_EXPRESSION, ValaAddressofExpressionClass))
#define VALA_IS_ADDRESSOF_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ADDRESSOF_EXPRESSION))
#define VALA_IS_ADDRESSOF_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ADDRESSOF_EXPRESSION))
#define VALA_ADDRESSOF_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ADDRESSOF_EXPRESSION, ValaAddressofExpressionClass))

typedef struct _ValaAddressofExpression ValaAddressofExpression;
typedef struct _ValaAddressofExpressionClass ValaAddressofExpressionClass;

#define VALA_TYPE_REFERENCE_TRANSFER_EXPRESSION (vala_reference_transfer_expression_get_type ())
#define VALA_REFERENCE_TRANSFER_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_REFERENCE_TRANSFER_EXPRESSION, ValaReferenceTransferExpression))
#define VALA_REFERENCE_TRANSFER_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_REFERENCE_TRANSFER_EXPRESSION, ValaReferenceTransferExpressionClass))
#define VALA_IS_REFERENCE_TRANSFER_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_REFERENCE_TRANSFER_EXPRESSION))
#define VALA_IS_REFERENCE_TRANSFER_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_REFERENCE_TRANSFER_EXPRESSION))
#define VALA_REFERENCE_TRANSFER_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_REFERENCE_TRANSFER_EXPRESSION, ValaReferenceTransferExpressionClass))

typedef struct _ValaReferenceTransferExpression ValaReferenceTransferExpression;
typedef struct _ValaReferenceTransferExpressionClass ValaReferenceTransferExpressionClass;

#define VALA_TYPE_BINARY_EXPRESSION (vala_binary_expression_get_type ())
#define VALA_BINARY_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_BINARY_EXPRESSION, ValaBinaryExpression))
#define VALA_BINARY_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_BINARY_EXPRESSION, ValaBinaryExpressionClass))
#define VALA_IS_BINARY_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_BINARY_EXPRESSION))
#define VALA_IS_BINARY_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_BINARY_EXPRESSION))
#define VALA_BINARY_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_BINARY_EXPRESSION, ValaBinaryExpressionClass))

typedef struct _ValaBinaryExpression ValaBinaryExpression;
typedef struct _ValaBinaryExpressionClass ValaBinaryExpressionClass;

#define VALA_TYPE_TYPECHECK (vala_typecheck_get_type ())
#define VALA_TYPECHECK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_TYPECHECK, ValaTypeCheck))
#define VALA_TYPECHECK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_TYPECHECK, ValaTypeCheckClass))
#define VALA_IS_TYPECHECK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_TYPECHECK))
#define VALA_IS_TYPECHECK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_TYPECHECK))
#define VALA_TYPECHECK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_TYPECHECK, ValaTypeCheckClass))

typedef struct _ValaTypeCheck ValaTypeCheck;
typedef struct _ValaTypeCheckClass ValaTypeCheckClass;

#define VALA_TYPE_CONDITIONAL_EXPRESSION (vala_conditional_expression_get_type ())
#define VALA_CONDITIONAL_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CONDITIONAL_EXPRESSION, ValaConditionalExpression))
#define VALA_CONDITIONAL_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CONDITIONAL_EXPRESSION, ValaConditionalExpressionClass))
#define VALA_IS_CONDITIONAL_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CONDITIONAL_EXPRESSION))
#define VALA_IS_CONDITIONAL_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CONDITIONAL_EXPRESSION))
#define VALA_CONDITIONAL_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CONDITIONAL_EXPRESSION, ValaConditionalExpressionClass))

typedef struct _ValaConditionalExpression ValaConditionalExpression;
typedef struct _ValaConditionalExpressionClass ValaConditionalExpressionClass;

#define VALA_TYPE_LAMBDA_EXPRESSION (vala_lambda_expression_get_type ())
#define VALA_LAMBDA_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LAMBDA_EXPRESSION, ValaLambdaExpression))
#define VALA_LAMBDA_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_LAMBDA_EXPRESSION, ValaLambdaExpressionClass))
#define VALA_IS_LAMBDA_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_LAMBDA_EXPRESSION))
#define VALA_IS_LAMBDA_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_LAMBDA_EXPRESSION))
#define VALA_LAMBDA_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_LAMBDA_EXPRESSION, ValaLambdaExpressionClass))

typedef struct _ValaLambdaExpression ValaLambdaExpression;
typedef struct _ValaLambdaExpressionClass ValaLambdaExpressionClass;

#define VALA_TYPE_ASSIGNMENT (vala_assignment_get_type ())
#define VALA_ASSIGNMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ASSIGNMENT, ValaAssignment))
#define VALA_ASSIGNMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ASSIGNMENT, ValaAssignmentClass))
#define VALA_IS_ASSIGNMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ASSIGNMENT))
#define VALA_IS_ASSIGNMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ASSIGNMENT))
#define VALA_ASSIGNMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ASSIGNMENT, ValaAssignmentClass))

typedef struct _ValaAssignment ValaAssignment;
typedef struct _ValaAssignmentClass ValaAssignmentClass;
typedef struct _ValaSemanticAnalyzerPrivate ValaSemanticAnalyzerPrivate;

#define VALA_TYPE_STATEMENT (vala_statement_get_type ())
#define VALA_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_STATEMENT, ValaStatement))
#define VALA_IS_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_STATEMENT))
#define VALA_STATEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), VALA_TYPE_STATEMENT, ValaStatementIface))

typedef struct _ValaStatement ValaStatement;
typedef struct _ValaStatementIface ValaStatementIface;

struct _ValaCodeNode {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ValaCodeNodePrivate * priv;
	GList* attributes;
};

struct _ValaCodeNodeClass {
	GTypeClass parent_class;
	void (*finalize) (ValaCodeNode *self);
	void (*accept) (ValaCodeNode* self, ValaCodeVisitor* visitor);
	void (*accept_children) (ValaCodeNode* self, ValaCodeVisitor* visitor);
	gboolean (*check) (ValaCodeNode* self, ValaCodeContext* context);
	void (*emit) (ValaCodeNode* self, ValaCodeGenerator* codegen);
	void (*replace_type) (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type);
	void (*replace_expression) (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node);
	gchar* (*to_string) (ValaCodeNode* self);
	void (*get_defined_variables) (ValaCodeNode* self, ValaCollection* collection);
	void (*get_used_variables) (ValaCodeNode* self, ValaCollection* collection);
};

struct _ValaExpression {
	ValaCodeNode parent_instance;
	ValaExpressionPrivate * priv;
};

struct _ValaExpressionClass {
	ValaCodeNodeClass parent_class;
	gboolean (*is_constant) (ValaExpression* self);
	gboolean (*is_pure) (ValaExpression* self);
	gboolean (*is_non_null) (ValaExpression* self);
};

struct _ValaObjectCreationExpression {
	ValaExpression parent_instance;
	ValaObjectCreationExpressionPrivate * priv;
};

struct _ValaObjectCreationExpressionClass {
	ValaExpressionClass parent_class;
};

struct _ValaObjectCreationExpressionPrivate {
	ValaMemberAccess* _member_name;
	gboolean _is_yield_expression;
	gboolean _struct_creation;
	ValaList* argument_list;
	ValaList* object_initializer;
	ValaDataType* _data_type;
};

typedef enum  {
	VALA_SYMBOL_ACCESSIBILITY_PRIVATE,
	VALA_SYMBOL_ACCESSIBILITY_INTERNAL,
	VALA_SYMBOL_ACCESSIBILITY_PROTECTED,
	VALA_SYMBOL_ACCESSIBILITY_PUBLIC
} ValaSymbolAccessibility;

struct _ValaCodeVisitor {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ValaCodeVisitorPrivate * priv;
};

struct _ValaCodeVisitorClass {
	GTypeClass parent_class;
	void (*finalize) (ValaCodeVisitor *self);
	void (*visit_source_file) (ValaCodeVisitor* self, ValaSourceFile* source_file);
	void (*visit_namespace) (ValaCodeVisitor* self, ValaNamespace* ns);
	void (*visit_class) (ValaCodeVisitor* self, ValaClass* cl);
	void (*visit_struct) (ValaCodeVisitor* self, ValaStruct* st);
	void (*visit_interface) (ValaCodeVisitor* self, ValaInterface* iface);
	void (*visit_enum) (ValaCodeVisitor* self, ValaEnum* en);
	void (*visit_enum_value) (ValaCodeVisitor* self, ValaEnumValue* ev);
	void (*visit_error_domain) (ValaCodeVisitor* self, ValaErrorDomain* edomain);
	void (*visit_error_code) (ValaCodeVisitor* self, ValaErrorCode* ecode);
	void (*visit_delegate) (ValaCodeVisitor* self, ValaDelegate* d);
	void (*visit_constant) (ValaCodeVisitor* self, ValaConstant* c);
	void (*visit_field) (ValaCodeVisitor* self, ValaField* f);
	void (*visit_method) (ValaCodeVisitor* self, ValaMethod* m);
	void (*visit_creation_method) (ValaCodeVisitor* self, ValaCreationMethod* m);
	void (*visit_formal_parameter) (ValaCodeVisitor* self, ValaParameter* p);
	void (*visit_property) (ValaCodeVisitor* self, ValaProperty* prop);
	void (*visit_property_accessor) (ValaCodeVisitor* self, ValaPropertyAccessor* acc);
	void (*visit_signal) (ValaCodeVisitor* self, ValaSignal* sig);
	void (*visit_constructor) (ValaCodeVisitor* self, ValaConstructor* c);
	void (*visit_destructor) (ValaCodeVisitor* self, ValaDestructor* d);
	void (*visit_type_parameter) (ValaCodeVisitor* self, ValaTypeParameter* p);
	void (*visit_using_directive) (ValaCodeVisitor* self, ValaUsingDirective* ns);
	void (*visit_data_type) (ValaCodeVisitor* self, ValaDataType* type);
	void (*visit_block) (ValaCodeVisitor* self, ValaBlock* b);
	void (*visit_empty_statement) (ValaCodeVisitor* self, ValaEmptyStatement* stmt);
	void (*visit_declaration_statement) (ValaCodeVisitor* self, ValaDeclarationStatement* stmt);
	void (*visit_local_variable) (ValaCodeVisitor* self, ValaLocalVariable* local);
	void (*visit_initializer_list) (ValaCodeVisitor* self, ValaInitializerList* list);
	void (*visit_expression_statement) (ValaCodeVisitor* self, ValaExpressionStatement* stmt);
	void (*visit_if_statement) (ValaCodeVisitor* self, ValaIfStatement* stmt);
	void (*visit_switch_statement) (ValaCodeVisitor* self, ValaSwitchStatement* stmt);
	void (*visit_switch_section) (ValaCodeVisitor* self, ValaSwitchSection* section);
	void (*visit_switch_label) (ValaCodeVisitor* self, ValaSwitchLabel* label);
	void (*visit_loop) (ValaCodeVisitor* self, ValaLoop* stmt);
	void (*visit_while_statement) (ValaCodeVisitor* self, ValaWhileStatement* stmt);
	void (*visit_do_statement) (ValaCodeVisitor* self, ValaDoStatement* stmt);
	void (*visit_for_statement) (ValaCodeVisitor* self, ValaForStatement* stmt);
	void (*visit_foreach_statement) (ValaCodeVisitor* self, ValaForeachStatement* stmt);
	void (*visit_break_statement) (ValaCodeVisitor* self, ValaBreakStatement* stmt);
	void (*visit_continue_statement) (ValaCodeVisitor* self, ValaContinueStatement* stmt);
	void (*visit_return_statement) (ValaCodeVisitor* self, ValaReturnStatement* stmt);
	void (*visit_yield_statement) (ValaCodeVisitor* self, ValaYieldStatement* y);
	void (*visit_throw_statement) (ValaCodeVisitor* self, ValaThrowStatement* stmt);
	void (*visit_try_statement) (ValaCodeVisitor* self, ValaTryStatement* stmt);
	void (*visit_catch_clause) (ValaCodeVisitor* self, ValaCatchClause* clause);
	void (*visit_lock_statement) (ValaCodeVisitor* self, ValaLockStatement* stmt);
	void (*visit_unlock_statement) (ValaCodeVisitor* self, ValaUnlockStatement* stmt);
	void (*visit_delete_statement) (ValaCodeVisitor* self, ValaDeleteStatement* stmt);
	void (*visit_expression) (ValaCodeVisitor* self, ValaExpression* expr);
	void (*visit_array_creation_expression) (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
	void (*visit_boolean_literal) (ValaCodeVisitor* self, ValaBooleanLiteral* lit);
	void (*visit_character_literal) (ValaCodeVisitor* self, ValaCharacterLiteral* lit);
	void (*visit_integer_literal) (ValaCodeVisitor* self, ValaIntegerLiteral* lit);
	void (*visit_real_literal) (ValaCodeVisitor* self, ValaRealLiteral* lit);
	void (*visit_regex_literal) (ValaCodeVisitor* self, ValaRegexLiteral* lit);
	void (*visit_string_literal) (ValaCodeVisitor* self, ValaStringLiteral* lit);
	void (*visit_template) (ValaCodeVisitor* self, ValaTemplate* tmpl);
	void (*visit_tuple) (ValaCodeVisitor* self, ValaTuple* tuple);
	void (*visit_null_literal) (ValaCodeVisitor* self, ValaNullLiteral* lit);
	void (*visit_member_access) (ValaCodeVisitor* self, ValaMemberAccess* expr);
	void (*visit_method_call) (ValaCodeVisitor* self, ValaMethodCall* expr);
	void (*visit_element_access) (ValaCodeVisitor* self, ValaElementAccess* expr);
	void (*visit_slice_expression) (ValaCodeVisitor* self, ValaSliceExpression* expr);
	void (*visit_base_access) (ValaCodeVisitor* self, ValaBaseAccess* expr);
	void (*visit_postfix_expression) (ValaCodeVisitor* self, ValaPostfixExpression* expr);
	void (*visit_object_creation_expression) (ValaCodeVisitor* self, ValaObjectCreationExpression* expr);
	void (*visit_sizeof_expression) (ValaCodeVisitor* self, ValaSizeofExpression* expr);
	void (*visit_typeof_expression) (ValaCodeVisitor* self, ValaTypeofExpression* expr);
	void (*visit_unary_expression) (ValaCodeVisitor* self, ValaUnaryExpression* expr);
	void (*visit_cast_expression) (ValaCodeVisitor* self, ValaCastExpression* expr);
	void (*visit_named_argument) (ValaCodeVisitor* self, ValaNamedArgument* expr);
	void (*visit_pointer_indirection) (ValaCodeVisitor* self, ValaPointerIndirection* expr);
	void (*visit_addressof_expression) (ValaCodeVisitor* self, ValaAddressofExpression* expr);
	void (*visit_reference_transfer_expression) (ValaCodeVisitor* self, ValaReferenceTransferExpression* expr);
	void (*visit_binary_expression) (ValaCodeVisitor* self, ValaBinaryExpression* expr);
	void (*visit_type_check) (ValaCodeVisitor* self, ValaTypeCheck* expr);
	void (*visit_conditional_expression) (ValaCodeVisitor* self, ValaConditionalExpression* expr);
	void (*visit_lambda_expression) (ValaCodeVisitor* self, ValaLambdaExpression* expr);
	void (*visit_assignment) (ValaCodeVisitor* self, ValaAssignment* a);
	void (*visit_end_full_expression) (ValaCodeVisitor* self, ValaExpression* expr);
};

struct _ValaSemanticAnalyzer {
	ValaCodeVisitor parent_instance;
	ValaSemanticAnalyzerPrivate * priv;
	ValaSymbol* root_symbol;
	ValaBlock* insert_block;
	ValaDataType* void_type;
	ValaDataType* bool_type;
	ValaDataType* string_type;
	ValaDataType* regex_type;
	ValaDataType* uchar_type;
	ValaDataType* short_type;
	ValaDataType* ushort_type;
	ValaDataType* int_type;
	ValaDataType* uint_type;
	ValaDataType* long_type;
	ValaDataType* ulong_type;
	ValaDataType* size_t_type;
	ValaDataType* ssize_t_type;
	ValaDataType* int8_type;
	ValaDataType* unichar_type;
	ValaDataType* double_type;
	ValaDataType* type_type;
	ValaDataType* va_list_type;
	ValaClass* object_type;
	ValaStructValueType* gvalue_type;
	ValaObjectType* gvariant_type;
	ValaDataType* glist_type;
	ValaDataType* gslist_type;
	ValaDataType* garray_type;
	ValaDataType* gvaluearray_type;
	ValaClass* gerror_type;
	ValaDataType* list_type;
	ValaDataType* tuple_type;
	ValaDataType* error_type;
	ValaClass* gsource_type;
	gint next_lambda_id;
	ValaList* replaced_nodes;
};

struct _ValaSemanticAnalyzerClass {
	ValaCodeVisitorClass parent_class;
};

struct _ValaStatementIface {
	GTypeInterface parent_iface;
};


static gpointer vala_object_creation_expression_parent_class = NULL;

gpointer vala_code_node_ref (gpointer instance);
void vala_code_node_unref (gpointer instance);
GParamSpec* vala_param_spec_code_node (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void vala_value_set_code_node (GValue* value, gpointer v_object);
void vala_value_take_code_node (GValue* value, gpointer v_object);
gpointer vala_value_get_code_node (const GValue* value);
GType vala_code_node_get_type (void) G_GNUC_CONST;
gpointer vala_code_visitor_ref (gpointer instance);
void vala_code_visitor_unref (gpointer instance);
GParamSpec* vala_param_spec_code_visitor (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void vala_value_set_code_visitor (GValue* value, gpointer v_object);
void vala_value_take_code_visitor (GValue* value, gpointer v_object);
gpointer vala_value_get_code_visitor (const GValue* value);
GType vala_code_visitor_get_type (void) G_GNUC_CONST;
gpointer vala_code_context_ref (gpointer instance);
void vala_code_context_unref (gpointer instance);
GParamSpec* vala_param_spec_code_context (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void vala_value_set_code_context (GValue* value, gpointer v_object);
void vala_value_take_code_context (GValue* value, gpointer v_object);
gpointer vala_value_get_code_context (const GValue* value);
GType vala_code_context_get_type (void) G_GNUC_CONST;
GType vala_code_generator_get_type (void) G_GNUC_CONST;
GType vala_data_type_get_type (void) G_GNUC_CONST;
GType vala_expression_get_type (void) G_GNUC_CONST;
GType vala_symbol_get_type (void) G_GNUC_CONST;
GType vala_variable_get_type (void) G_GNUC_CONST;
GType vala_attribute_get_type (void) G_GNUC_CONST;
GType vala_object_creation_expression_get_type (void) G_GNUC_CONST;
GType vala_member_access_get_type (void) G_GNUC_CONST;
GType vala_member_initializer_get_type (void) G_GNUC_CONST;
#define VALA_OBJECT_CREATION_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_OBJECT_CREATION_EXPRESSION, ValaObjectCreationExpressionPrivate))
enum  {
	VALA_OBJECT_CREATION_EXPRESSION_DUMMY_PROPERTY
};
gpointer vala_source_reference_ref (gpointer instance);
void vala_source_reference_unref (gpointer instance);
GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void vala_value_set_source_reference (GValue* value, gpointer v_object);
void vala_value_take_source_reference (GValue* value, gpointer v_object);
gpointer vala_value_get_source_reference (const GValue* value);
GType vala_source_reference_get_type (void) G_GNUC_CONST;
ValaObjectCreationExpression* vala_object_creation_expression_new (ValaMemberAccess* member_name, ValaSourceReference* source_reference);
ValaObjectCreationExpression* vala_object_creation_expression_construct (GType object_type, ValaMemberAccess* member_name, ValaSourceReference* source_reference);
ValaExpression* vala_expression_construct (GType object_type);
void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
void vala_object_creation_expression_set_member_name (ValaObjectCreationExpression* self, ValaMemberAccess* value);
void vala_object_creation_expression_add_argument (ValaObjectCreationExpression* self, ValaExpression* arg);
void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
ValaList* vala_object_creation_expression_get_argument_list (ValaObjectCreationExpression* self);
void vala_object_creation_expression_add_member_initializer (ValaObjectCreationExpression* self, ValaMemberInitializer* init);
ValaList* vala_object_creation_expression_get_object_initializer (ValaObjectCreationExpression* self);
static void vala_object_creation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
void vala_code_visitor_visit_object_creation_expression (ValaCodeVisitor* self, ValaObjectCreationExpression* expr);
void vala_code_visitor_visit_expression (ValaCodeVisitor* self, ValaExpression* expr);
static void vala_object_creation_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
ValaDataType* vala_object_creation_expression_get_type_reference (ValaObjectCreationExpression* self);
void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
ValaMemberAccess* vala_object_creation_expression_get_member_name (ValaObjectCreationExpression* self);
static void vala_object_creation_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
ValaCodeNode* vala_code_node_get_parent_node (ValaCodeNode* self);
static gboolean vala_object_creation_expression_real_is_pure (ValaExpression* base);
static void vala_object_creation_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
void vala_object_creation_expression_set_type_reference (ValaObjectCreationExpression* self, ValaDataType* value);
static gboolean vala_object_creation_expression_real_check (ValaCodeNode* base, ValaCodeContext* context);
gboolean vala_code_node_get_checked (ValaCodeNode* self);
gboolean vala_code_node_get_error (ValaCodeNode* self);
void vala_code_node_set_checked (ValaCodeNode* self, gboolean value);
gboolean vala_code_node_check (ValaCodeNode* self, ValaCodeContext* context);
GType vala_typesymbol_get_type (void) G_GNUC_CONST;
void vala_code_node_set_error (ValaCodeNode* self, gboolean value);
void vala_report_error (ValaSourceReference* source, const gchar* message);
ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self);
ValaSymbol* vala_expression_get_symbol_reference (ValaExpression* self);
ValaList* vala_member_access_get_type_arguments (ValaMemberAccess* self);
GType vala_subroutine_get_type (void) G_GNUC_CONST;
GType vala_method_get_type (void) G_GNUC_CONST;
ValaSymbol* vala_symbol_get_parent_symbol (ValaSymbol* self);
GType vala_creation_method_get_type (void) G_GNUC_CONST;
gchar* vala_symbol_get_full_name (ValaSymbol* self);
void vala_expression_set_symbol_reference (ValaExpression* self, ValaSymbol* value);
ValaExpression* vala_member_access_get_inner (ValaMemberAccess* self);
GType vala_object_type_symbol_get_type (void) G_GNUC_CONST;
GType vala_class_get_type (void) G_GNUC_CONST;
gboolean vala_class_get_is_error_base (ValaClass* self);
GType vala_error_domain_get_type (void) G_GNUC_CONST;
GType vala_error_code_get_type (void) G_GNUC_CONST;
ValaErrorType* vala_error_type_new (ValaErrorDomain* error_domain, ValaErrorCode* error_code, ValaSourceReference* source_reference);
ValaErrorType* vala_error_type_construct (GType object_type, ValaErrorDomain* error_domain, ValaErrorCode* error_code, ValaSourceReference* source_reference);
GType vala_reference_type_get_type (void) G_GNUC_CONST;
GType vala_error_type_get_type (void) G_GNUC_CONST;
ValaObjectType* vala_object_type_new (ValaObjectTypeSymbol* type_symbol);
ValaObjectType* vala_object_type_construct (GType object_type, ValaObjectTypeSymbol* type_symbol);
GType vala_object_type_get_type (void) G_GNUC_CONST;
GType vala_struct_get_type (void) G_GNUC_CONST;
ValaStructValueType* vala_struct_value_type_new (ValaStruct* type_symbol);
ValaStructValueType* vala_struct_value_type_construct (GType object_type, ValaStruct* type_symbol);
GType vala_value_type_get_type (void) G_GNUC_CONST;
GType vala_struct_value_type_get_type (void) G_GNUC_CONST;
void vala_data_type_add_type_argument (ValaDataType* self, ValaDataType* arg);
ValaTypeSymbol* vala_data_type_get_data_type (ValaDataType* self);
ValaDataType* vala_data_type_copy (ValaDataType* self);
void vala_expression_set_value_type (ValaExpression* self, ValaDataType* value);
ValaDataType* vala_expression_get_value_type (ValaExpression* self);
void vala_data_type_set_value_owned (ValaDataType* self, gboolean value);
ValaList* vala_data_type_get_type_arguments (ValaDataType* self);
GType vala_typeparameter_get_type (void) G_GNUC_CONST;
ValaList* vala_object_type_symbol_get_type_parameters (ValaObjectTypeSymbol* self);
gboolean vala_object_creation_expression_get_struct_creation (ValaObjectCreationExpression* self);
gboolean vala_class_get_is_abstract (ValaClass* self);
ValaCreationMethod* vala_class_get_default_construction_method (ValaClass* self);
void vala_symbol_set_used (ValaSymbol* self, gboolean value);
gboolean vala_symbol_check_deprecated (ValaSymbol* self, ValaSourceReference* source_ref);
GType vala_symbol_accessibility_get_type (void) G_GNUC_CONST;
ValaSymbolAccessibility vala_symbol_get_access (ValaSymbol* self);
GType vala_semantic_analyzer_get_type (void) G_GNUC_CONST;
ValaSemanticAnalyzer* vala_code_context_get_analyzer (ValaCodeContext* self);
ValaSymbol* vala_semantic_analyzer_get_current_symbol (ValaSemanticAnalyzer* self);
gchar* vala_code_node_get_attribute_string (ValaCodeNode* self, const gchar* attribute, const gchar* argument, const gchar* default_value);
void vala_data_type_set_floating_reference (ValaDataType* self, gboolean value);
ValaClass* vala_class_get_base_class (ValaClass* self);
ValaList* vala_struct_get_type_parameters (ValaStruct* self);
gboolean vala_code_context_get_deprecated (ValaCodeContext* self);
void vala_report_warning (ValaSourceReference* source, const gchar* message);
ValaMethod* vala_struct_get_default_construction_method (ValaStruct* self);
gboolean vala_struct_is_simple_type (ValaStruct* self);
gboolean vala_object_creation_expression_get_is_yield_expression (ValaObjectCreationExpression* self);
gboolean vala_method_get_coroutine (ValaMethod* self);
ValaMethod* vala_semantic_analyzer_get_current_method (ValaSemanticAnalyzer* self);
gint vala_method_get_yield_count (ValaMethod* self);
void vala_method_set_yield_count (ValaMethod* self, gint value);
GType vala_parameter_get_type (void) G_GNUC_CONST;
ValaList* vala_method_get_parameters (ValaMethod* self);
gboolean vala_parameter_get_ellipsis (ValaParameter* self);
ValaDataType* vala_variable_get_variable_type (ValaVariable* self);
void vala_expression_set_formal_target_type (ValaExpression* self, ValaDataType* value);
ValaDataType* vala_expression_get_formal_target_type (ValaExpression* self);
ValaDataType* vala_data_type_get_actual_type (ValaDataType* self, ValaDataType* derived_instance_type, ValaMemberAccess* method_access, ValaCodeNode* node_reference);
void vala_expression_set_target_type (ValaExpression* self, ValaDataType* value);
gboolean vala_semantic_analyzer_check_arguments (ValaSemanticAnalyzer* self, ValaExpression* expr, ValaDataType* mtype, ValaList* params, ValaList* args);
ValaMethodType* vala_method_type_new (ValaMethod* method_symbol);
ValaMethodType* vala_method_type_construct (GType object_type, ValaMethod* method_symbol);
GType vala_method_type_get_type (void) G_GNUC_CONST;
ValaList* vala_code_node_get_error_types (ValaCodeNode* self);
void vala_code_node_add_error_type (ValaCodeNode* self, ValaDataType* error_type);
gboolean vala_data_type_compatible (ValaDataType* self, ValaDataType* target_type);
gpointer vala_source_file_ref (gpointer instance);
void vala_source_file_unref (gpointer instance);
GParamSpec* vala_param_spec_source_file (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void vala_value_set_source_file (GValue* value, gpointer v_object);
void vala_value_take_source_file (GValue* value, gpointer v_object);
gpointer vala_value_get_source_file (const GValue* value);
GType vala_source_file_get_type (void) G_GNUC_CONST;
GType vala_namespace_get_type (void) G_GNUC_CONST;
GType vala_interface_get_type (void) G_GNUC_CONST;
GType vala_enum_get_type (void) G_GNUC_CONST;
GType vala_constant_get_type (void) G_GNUC_CONST;
GType vala_enum_value_get_type (void) G_GNUC_CONST;
GType vala_delegate_get_type (void) G_GNUC_CONST;
GType vala_field_get_type (void) G_GNUC_CONST;
GType vala_property_get_type (void) G_GNUC_CONST;
GType vala_property_accessor_get_type (void) G_GNUC_CONST;
GType vala_signal_get_type (void) G_GNUC_CONST;
GType vala_constructor_get_type (void) G_GNUC_CONST;
GType vala_destructor_get_type (void) G_GNUC_CONST;
GType vala_using_directive_get_type (void) G_GNUC_CONST;
GType vala_block_get_type (void) G_GNUC_CONST;
GType vala_empty_statement_get_type (void) G_GNUC_CONST;
GType vala_declaration_statement_get_type (void) G_GNUC_CONST;
GType vala_local_variable_get_type (void) G_GNUC_CONST;
GType vala_initializer_list_get_type (void) G_GNUC_CONST;
GType vala_expression_statement_get_type (void) G_GNUC_CONST;
GType vala_if_statement_get_type (void) G_GNUC_CONST;
GType vala_switch_statement_get_type (void) G_GNUC_CONST;
GType vala_switch_section_get_type (void) G_GNUC_CONST;
GType vala_switch_label_get_type (void) G_GNUC_CONST;
GType vala_loop_get_type (void) G_GNUC_CONST;
GType vala_while_statement_get_type (void) G_GNUC_CONST;
GType vala_do_statement_get_type (void) G_GNUC_CONST;
GType vala_for_statement_get_type (void) G_GNUC_CONST;
GType vala_foreach_statement_get_type (void) G_GNUC_CONST;
GType vala_break_statement_get_type (void) G_GNUC_CONST;
GType vala_continue_statement_get_type (void) G_GNUC_CONST;
GType vala_return_statement_get_type (void) G_GNUC_CONST;
GType vala_yield_statement_get_type (void) G_GNUC_CONST;
GType vala_throw_statement_get_type (void) G_GNUC_CONST;
GType vala_try_statement_get_type (void) G_GNUC_CONST;
GType vala_catch_clause_get_type (void) G_GNUC_CONST;
GType vala_lock_statement_get_type (void) G_GNUC_CONST;
GType vala_unlock_statement_get_type (void) G_GNUC_CONST;
GType vala_delete_statement_get_type (void) G_GNUC_CONST;
GType vala_array_creation_expression_get_type (void) G_GNUC_CONST;
GType vala_literal_get_type (void) G_GNUC_CONST;
GType vala_boolean_literal_get_type (void) G_GNUC_CONST;
GType vala_character_literal_get_type (void) G_GNUC_CONST;
GType vala_integer_literal_get_type (void) G_GNUC_CONST;
GType vala_real_literal_get_type (void) G_GNUC_CONST;
GType vala_regex_literal_get_type (void) G_GNUC_CONST;
GType vala_string_literal_get_type (void) G_GNUC_CONST;
GType vala_template_get_type (void) G_GNUC_CONST;
GType vala_tuple_get_type (void) G_GNUC_CONST;
GType vala_null_literal_get_type (void) G_GNUC_CONST;
GType vala_method_call_get_type (void) G_GNUC_CONST;
GType vala_element_access_get_type (void) G_GNUC_CONST;
GType vala_slice_expression_get_type (void) G_GNUC_CONST;
GType vala_base_access_get_type (void) G_GNUC_CONST;
GType vala_postfix_expression_get_type (void) G_GNUC_CONST;
GType vala_sizeof_expression_get_type (void) G_GNUC_CONST;
GType vala_typeof_expression_get_type (void) G_GNUC_CONST;
GType vala_unary_expression_get_type (void) G_GNUC_CONST;
GType vala_cast_expression_get_type (void) G_GNUC_CONST;
GType vala_named_argument_get_type (void) G_GNUC_CONST;
GType vala_pointer_indirection_get_type (void) G_GNUC_CONST;
GType vala_addressof_expression_get_type (void) G_GNUC_CONST;
GType vala_reference_transfer_expression_get_type (void) G_GNUC_CONST;
GType vala_binary_expression_get_type (void) G_GNUC_CONST;
GType vala_typecheck_get_type (void) G_GNUC_CONST;
GType vala_conditional_expression_get_type (void) G_GNUC_CONST;
GType vala_lambda_expression_get_type (void) G_GNUC_CONST;
GType vala_assignment_get_type (void) G_GNUC_CONST;
gchar* vala_string_literal_eval (ValaStringLiteral* self);
gboolean vala_semantic_analyzer_check_print_format (ValaSemanticAnalyzer* self, const gchar* format, ValaIterator* arg_it, ValaSourceReference* source_reference);
gboolean vala_semantic_analyzer_check_variadic_arguments (ValaSemanticAnalyzer* self, ValaIterator* arg_it, gint i, ValaSourceReference* source_reference);
void vala_semantic_analyzer_visit_member_initializer (ValaSemanticAnalyzer* self, ValaMemberInitializer* init, ValaDataType* type);
gchar* vala_code_node_get_temp_name (void);
ValaLocalVariable* vala_local_variable_new (ValaDataType* variable_type, const gchar* name, ValaExpression* initializer, ValaSourceReference* source_reference);
ValaLocalVariable* vala_local_variable_construct (GType object_type, ValaDataType* variable_type, const gchar* name, ValaExpression* initializer, ValaSourceReference* source_reference);
ValaDeclarationStatement* vala_declaration_statement_new (ValaSymbol* declaration, ValaSourceReference* source_reference);
ValaDeclarationStatement* vala_declaration_statement_construct (GType object_type, ValaSymbol* declaration, ValaSourceReference* source_reference);
GType vala_statement_get_type (void) G_GNUC_CONST;
void vala_expression_insert_statement (ValaExpression* self, ValaBlock* block, ValaStatement* stmt);
ValaExpression* vala_semantic_analyzer_create_temp_access (ValaLocalVariable* local, ValaDataType* target_type);
ValaDataType* vala_expression_get_target_type (ValaExpression* self);
void vala_variable_set_initializer (ValaVariable* self, ValaExpression* value);
void vala_block_remove_local_variable (ValaBlock* self, ValaLocalVariable* local);
void vala_block_add_local_variable (ValaBlock* self, ValaLocalVariable* local);
void vala_code_node_replace_expression (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node);
static void vala_object_creation_expression_real_emit (ValaCodeNode* base, ValaCodeGenerator* codegen);
void vala_code_node_emit (ValaCodeNode* self, ValaCodeGenerator* codegen);
static void vala_object_creation_expression_real_get_defined_variables (ValaCodeNode* base, ValaCollection* collection);
void vala_code_node_get_defined_variables (ValaCodeNode* self, ValaCollection* collection);
static void vala_object_creation_expression_real_get_used_variables (ValaCodeNode* base, ValaCollection* collection);
void vala_code_node_get_used_variables (ValaCodeNode* self, ValaCollection* collection);
void vala_object_creation_expression_set_is_yield_expression (ValaObjectCreationExpression* self, gboolean value);
void vala_object_creation_expression_set_struct_creation (ValaObjectCreationExpression* self, gboolean value);
static void vala_object_creation_expression_finalize (ValaCodeNode* obj);


/**
 * Creates a new object creation expression.
 *
 * @param member_name      object type to create
 * @param source_reference reference to source code
 * @return                 newly created object creation expression
 */
ValaObjectCreationExpression* vala_object_creation_expression_construct (GType object_type, ValaMemberAccess* member_name, ValaSourceReference* source_reference) {
	ValaObjectCreationExpression* self = NULL;
	ValaSourceReference* _tmp0_ = NULL;
	ValaMemberAccess* _tmp1_ = NULL;
	g_return_val_if_fail (member_name != NULL, NULL);
	g_return_val_if_fail (source_reference != NULL, NULL);
	self = (ValaObjectCreationExpression*) vala_expression_construct (object_type);
	_tmp0_ = source_reference;
	vala_code_node_set_source_reference ((ValaCodeNode*) self, _tmp0_);
	_tmp1_ = member_name;
	vala_object_creation_expression_set_member_name (self, _tmp1_);
	return self;
}


ValaObjectCreationExpression* vala_object_creation_expression_new (ValaMemberAccess* member_name, ValaSourceReference* source_reference) {
	return vala_object_creation_expression_construct (VALA_TYPE_OBJECT_CREATION_EXPRESSION, member_name, source_reference);
}


/**
 * Appends the specified expression to the list of arguments.
 *
 * @param arg an argument
 */
void vala_object_creation_expression_add_argument (ValaObjectCreationExpression* self, ValaExpression* arg) {
	ValaList* _tmp0_ = NULL;
	ValaExpression* _tmp1_ = NULL;
	ValaExpression* _tmp2_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (arg != NULL);
	_tmp0_ = self->priv->argument_list;
	_tmp1_ = arg;
	vala_collection_add ((ValaCollection*) _tmp0_, _tmp1_);
	_tmp2_ = arg;
	vala_code_node_set_parent_node ((ValaCodeNode*) _tmp2_, (ValaCodeNode*) self);
}


/**
 * Returns a copy of the argument list.
 *
 * @return argument list
 */
static gpointer _vala_iterable_ref0 (gpointer self) {
	return self ? vala_iterable_ref (self) : NULL;
}


ValaList* vala_object_creation_expression_get_argument_list (ValaObjectCreationExpression* self) {
	ValaList* result = NULL;
	ValaList* _tmp0_ = NULL;
	ValaList* _tmp1_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->argument_list;
	_tmp1_ = _vala_iterable_ref0 (_tmp0_);
	result = _tmp1_;
	return result;
}


/**
 * Appends the specified member initializer to the object initializer.
 *
 * @param init a member initializer
 */
void vala_object_creation_expression_add_member_initializer (ValaObjectCreationExpression* self, ValaMemberInitializer* init) {
	ValaList* _tmp0_ = NULL;
	ValaMemberInitializer* _tmp1_ = NULL;
	ValaMemberInitializer* _tmp2_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (init != NULL);
	_tmp0_ = self->priv->object_initializer;
	_tmp1_ = init;
	vala_collection_add ((ValaCollection*) _tmp0_, _tmp1_);
	_tmp2_ = init;
	vala_code_node_set_parent_node ((ValaCodeNode*) _tmp2_, (ValaCodeNode*) self);
}


/**
 * Returns the object initializer.
 *
 * @return member initializer list
 */
ValaList* vala_object_creation_expression_get_object_initializer (ValaObjectCreationExpression* self) {
	ValaList* result = NULL;
	ValaList* _tmp0_ = NULL;
	ValaList* _tmp1_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->object_initializer;
	_tmp1_ = _vala_iterable_ref0 (_tmp0_);
	result = _tmp1_;
	return result;
}


static void vala_object_creation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
	ValaObjectCreationExpression * self;
	ValaCodeVisitor* _tmp0_ = NULL;
	ValaCodeVisitor* _tmp1_ = NULL;
	self = (ValaObjectCreationExpression*) base;
	g_return_if_fail (visitor != NULL);
	_tmp0_ = visitor;
	vala_code_visitor_visit_object_creation_expression (_tmp0_, self);
	_tmp1_ = visitor;
	vala_code_visitor_visit_expression (_tmp1_, (ValaExpression*) self);
}


static void vala_object_creation_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
	ValaObjectCreationExpression * self;
	ValaDataType* _tmp0_ = NULL;
	ValaDataType* _tmp1_ = NULL;
	ValaMemberAccess* _tmp5_ = NULL;
	self = (ValaObjectCreationExpression*) base;
	g_return_if_fail (visitor != NULL);
	_tmp0_ = vala_object_creation_expression_get_type_reference (self);
	_tmp1_ = _tmp0_;
	if (_tmp1_ != NULL) {
		ValaDataType* _tmp2_ = NULL;
		ValaDataType* _tmp3_ = NULL;
		ValaCodeVisitor* _tmp4_ = NULL;
		_tmp2_ = vala_object_creation_expression_get_type_reference (self);
		_tmp3_ = _tmp2_;
		_tmp4_ = visitor;
		vala_code_node_accept ((ValaCodeNode*) _tmp3_, _tmp4_);
	}
	_tmp5_ = self->priv->_member_name;
	if (_tmp5_ != NULL) {
		ValaMemberAccess* _tmp6_ = NULL;
		ValaCodeVisitor* _tmp7_ = NULL;
		_tmp6_ = self->priv->_member_name;
		_tmp7_ = visitor;
		vala_code_node_accept ((ValaCodeNode*) _tmp6_, _tmp7_);
	}
	{
		ValaList* _arg_list = NULL;
		ValaList* _tmp8_ = NULL;
		ValaList* _tmp9_ = NULL;
		gint _arg_size = 0;
		ValaList* _tmp10_ = NULL;
		gint _tmp11_ = 0;
		gint _tmp12_ = 0;
		gint _arg_index = 0;
		_tmp8_ = self->priv->argument_list;
		_tmp9_ = _vala_iterable_ref0 (_tmp8_);
		_arg_list = _tmp9_;
		_tmp10_ = _arg_list;
		_tmp11_ = vala_collection_get_size ((ValaCollection*) _tmp10_);
		_tmp12_ = _tmp11_;
		_arg_size = _tmp12_;
		_arg_index = -1;
		while (TRUE) {
			gint _tmp13_ = 0;
			gint _tmp14_ = 0;
			gint _tmp15_ = 0;
			ValaExpression* arg = NULL;
			ValaList* _tmp16_ = NULL;
			gint _tmp17_ = 0;
			gpointer _tmp18_ = NULL;
			ValaExpression* _tmp19_ = NULL;
			ValaCodeVisitor* _tmp20_ = NULL;
			_tmp13_ = _arg_index;
			_arg_index = _tmp13_ + 1;
			_tmp14_ = _arg_index;
			_tmp15_ = _arg_size;
			if (!(_tmp14_ < _tmp15_)) {
				break;
			}
			_tmp16_ = _arg_list;
			_tmp17_ = _arg_index;
			_tmp18_ = vala_list_get (_tmp16_, _tmp17_);
			arg = (ValaExpression*) _tmp18_;
			_tmp19_ = arg;
			_tmp20_ = visitor;
			vala_code_node_accept ((ValaCodeNode*) _tmp19_, _tmp20_);
			_vala_code_node_unref0 (arg);
		}
		_vala_iterable_unref0 (_arg_list);
	}
	{
		ValaList* _init_list = NULL;
		ValaList* _tmp21_ = NULL;
		ValaList* _tmp22_ = NULL;
		gint _init_size = 0;
		ValaList* _tmp23_ = NULL;
		gint _tmp24_ = 0;
		gint _tmp25_ = 0;
		gint _init_index = 0;
		_tmp21_ = self->priv->object_initializer;
		_tmp22_ = _vala_iterable_ref0 (_tmp21_);
		_init_list = _tmp22_;
		_tmp23_ = _init_list;
		_tmp24_ = vala_collection_get_size ((ValaCollection*) _tmp23_);
		_tmp25_ = _tmp24_;
		_init_size = _tmp25_;
		_init_index = -1;
		while (TRUE) {
			gint _tmp26_ = 0;
			gint _tmp27_ = 0;
			gint _tmp28_ = 0;
			ValaMemberInitializer* init = NULL;
			ValaList* _tmp29_ = NULL;
			gint _tmp30_ = 0;
			gpointer _tmp31_ = NULL;
			ValaMemberInitializer* _tmp32_ = NULL;
			ValaCodeVisitor* _tmp33_ = NULL;
			_tmp26_ = _init_index;
			_init_index = _tmp26_ + 1;
			_tmp27_ = _init_index;
			_tmp28_ = _init_size;
			if (!(_tmp27_ < _tmp28_)) {
				break;
			}
			_tmp29_ = _init_list;
			_tmp30_ = _init_index;
			_tmp31_ = vala_list_get (_tmp29_, _tmp30_);
			init = (ValaMemberInitializer*) _tmp31_;
			_tmp32_ = init;
			_tmp33_ = visitor;
			vala_code_node_accept ((ValaCodeNode*) _tmp32_, _tmp33_);
			_vala_code_node_unref0 (init);
		}
		_vala_iterable_unref0 (_init_list);
	}
}


static void vala_object_creation_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
	ValaObjectCreationExpression * self;
	gint index = 0;
	ValaList* _tmp0_ = NULL;
	ValaExpression* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	gboolean _tmp3_ = FALSE;
	gint _tmp4_ = 0;
	self = (ValaObjectCreationExpression*) base;
	g_return_if_fail (old_node != NULL);
	g_return_if_fail (new_node != NULL);
	_tmp0_ = self->priv->argument_list;
	_tmp1_ = old_node;
	_tmp2_ = vala_list_index_of (_tmp0_, _tmp1_);
	index = _tmp2_;
	_tmp4_ = index;
	if (_tmp4_ >= 0) {
		ValaExpression* _tmp5_ = NULL;
		ValaCodeNode* _tmp6_ = NULL;
		ValaCodeNode* _tmp7_ = NULL;
		_tmp5_ = new_node;
		_tmp6_ = vala_code_node_get_parent_node ((ValaCodeNode*) _tmp5_);
		_tmp7_ = _tmp6_;
		_tmp3_ = _tmp7_ == NULL;
	} else {
		_tmp3_ = FALSE;
	}
	if (_tmp3_) {
		ValaList* _tmp8_ = NULL;
		gint _tmp9_ = 0;
		ValaExpression* _tmp10_ = NULL;
		ValaExpression* _tmp11_ = NULL;
		_tmp8_ = self->priv->argument_list;
		_tmp9_ = index;
		_tmp10_ = new_node;
		vala_list_set (_tmp8_, _tmp9_, _tmp10_);
		_tmp11_ = new_node;
		vala_code_node_set_parent_node ((ValaCodeNode*) _tmp11_, (ValaCodeNode*) self);
	}
}


static gboolean vala_object_creation_expression_real_is_pure (ValaExpression* base) {
	ValaObjectCreationExpression * self;
	gboolean result = FALSE;
	self = (ValaObjectCreationExpression*) base;
	result = FALSE;
	return result;
}


static void vala_object_creation_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
	ValaObjectCreationExpression * self;
	ValaDataType* _tmp0_ = NULL;
	ValaDataType* _tmp1_ = NULL;
	ValaDataType* _tmp2_ = NULL;
	self = (ValaObjectCreationExpression*) base;
	g_return_if_fail (old_type != NULL);
	g_return_if_fail (new_type != NULL);
	_tmp0_ = vala_object_creation_expression_get_type_reference (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = old_type;
	if (_tmp1_ == _tmp2_) {
		ValaDataType* _tmp3_ = NULL;
		_tmp3_ = new_type;
		vala_object_creation_expression_set_type_reference (self, _tmp3_);
	}
}


static gpointer _vala_code_node_ref0 (gpointer self) {
	return self ? vala_code_node_ref (self) : NULL;
}


static gboolean vala_object_creation_expression_real_check (ValaCodeNode* base, ValaCodeContext* context) {
	ValaObjectCreationExpression * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	ValaMemberAccess* _tmp4_ = NULL;
	ValaTypeSymbol* type = NULL;
	ValaDataType* _tmp7_ = NULL;
	ValaDataType* _tmp8_ = NULL;
	ValaDataType* _tmp103_ = NULL;
	ValaDataType* _tmp104_ = NULL;
	ValaDataType* _tmp105_ = NULL;
	ValaDataType* _tmp106_ = NULL;
	ValaDataType* _tmp107_ = NULL;
	ValaDataType* _tmp108_ = NULL;
	gboolean may_throw = FALSE;
	gint given_num_type_args = 0;
	ValaDataType* _tmp109_ = NULL;
	ValaDataType* _tmp110_ = NULL;
	ValaList* _tmp111_ = NULL;
	ValaList* _tmp112_ = NULL;
	gint _tmp113_ = 0;
	gint _tmp114_ = 0;
	gint _tmp115_ = 0;
	gint expected_num_type_args = 0;
	ValaTypeSymbol* _tmp116_ = NULL;
	gint _tmp234_ = 0;
	gint _tmp235_ = 0;
	gboolean _tmp242_ = FALSE;
	ValaSymbol* _tmp243_ = NULL;
	ValaSymbol* _tmp244_ = NULL;
	ValaSymbol* _tmp256_ = NULL;
	ValaSymbol* _tmp257_ = NULL;
	gboolean _tmp466_ = FALSE;
	gboolean _tmp525_ = FALSE;
	gboolean _tmp526_ = FALSE;
	self = (ValaObjectCreationExpression*) base;
	g_return_val_if_fail (context != NULL, FALSE);
	_tmp0_ = vala_code_node_get_checked ((ValaCodeNode*) self);
	_tmp1_ = _tmp0_;
	if (_tmp1_) {
		gboolean _tmp2_ = FALSE;
		gboolean _tmp3_ = FALSE;
		_tmp2_ = vala_code_node_get_error ((ValaCodeNode*) self);
		_tmp3_ = _tmp2_;
		result = !_tmp3_;
		return result;
	}
	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
	_tmp4_ = self->priv->_member_name;
	if (_tmp4_ != NULL) {
		ValaMemberAccess* _tmp5_ = NULL;
		ValaCodeContext* _tmp6_ = NULL;
		_tmp5_ = self->priv->_member_name;
		_tmp6_ = context;
		vala_code_node_check ((ValaCodeNode*) _tmp5_, _tmp6_);
	}
	type = NULL;
	_tmp7_ = vala_object_creation_expression_get_type_reference (self);
	_tmp8_ = _tmp7_;
	if (_tmp8_ == NULL) {
		ValaMemberAccess* _tmp9_ = NULL;
		ValaMemberAccess* _tmp12_ = NULL;
		ValaSymbol* _tmp13_ = NULL;
		ValaSymbol* _tmp14_ = NULL;
		ValaSymbol* constructor_sym = NULL;
		ValaMemberAccess* _tmp15_ = NULL;
		ValaSymbol* _tmp16_ = NULL;
		ValaSymbol* _tmp17_ = NULL;
		ValaSymbol* _tmp18_ = NULL;
		ValaSymbol* type_sym = NULL;
		ValaMemberAccess* _tmp19_ = NULL;
		ValaSymbol* _tmp20_ = NULL;
		ValaSymbol* _tmp21_ = NULL;
		ValaSymbol* _tmp22_ = NULL;
		ValaList* type_args = NULL;
		ValaMemberAccess* _tmp23_ = NULL;
		ValaList* _tmp24_ = NULL;
		ValaSymbol* _tmp25_ = NULL;
		ValaSymbol* _tmp48_ = NULL;
		_tmp9_ = self->priv->_member_name;
		if (_tmp9_ == NULL) {
			ValaSourceReference* _tmp10_ = NULL;
			ValaSourceReference* _tmp11_ = NULL;
			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
			_tmp10_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
			_tmp11_ = _tmp10_;
			vala_report_error (_tmp11_, "Incomplete object creation expression");
			result = FALSE;
			_vala_code_node_unref0 (type);
			return result;
		}
		_tmp12_ = self->priv->_member_name;
		_tmp13_ = vala_expression_get_symbol_reference ((ValaExpression*) _tmp12_);
		_tmp14_ = _tmp13_;
		if (_tmp14_ == NULL) {
			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
			result = FALSE;
			_vala_code_node_unref0 (type);
			return result;
		}
		_tmp15_ = self->priv->_member_name;
		_tmp16_ = vala_expression_get_symbol_reference ((ValaExpression*) _tmp15_);
		_tmp17_ = _tmp16_;
		_tmp18_ = _vala_code_node_ref0 (_tmp17_);
		constructor_sym = _tmp18_;
		_tmp19_ = self->priv->_member_name;
		_tmp20_ = vala_expression_get_symbol_reference ((ValaExpression*) _tmp19_);
		_tmp21_ = _tmp20_;
		_tmp22_ = _vala_code_node_ref0 (_tmp21_);
		type_sym = _tmp22_;
		_tmp23_ = self->priv->_member_name;
		_tmp24_ = vala_member_access_get_type_arguments (_tmp23_);
		type_args = _tmp24_;
		_tmp25_ = constructor_sym;
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp25_, VALA_TYPE_METHOD)) {
			ValaSymbol* _tmp26_ = NULL;
			ValaSymbol* _tmp27_ = NULL;
			ValaSymbol* _tmp28_ = NULL;
			ValaSymbol* _tmp29_ = NULL;
			ValaMethod* constructor = NULL;
			ValaSymbol* _tmp30_ = NULL;
			ValaMethod* _tmp31_ = NULL;
			ValaSymbol* _tmp32_ = NULL;
			ValaMethod* _tmp40_ = NULL;
			ValaMemberAccess* ma = NULL;
			ValaMemberAccess* _tmp41_ = NULL;
			ValaExpression* _tmp42_ = NULL;
			ValaExpression* _tmp43_ = NULL;
			ValaMemberAccess* _tmp44_ = NULL;
			ValaMemberAccess* _tmp45_ = NULL;
			_tmp26_ = constructor_sym;
			_tmp27_ = vala_symbol_get_parent_symbol (_tmp26_);
			_tmp28_ = _tmp27_;
			_tmp29_ = _vala_code_node_ref0 (_tmp28_);
			_vala_code_node_unref0 (type_sym);
			type_sym = _tmp29_;
			_tmp30_ = constructor_sym;
			_tmp31_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, VALA_TYPE_METHOD, ValaMethod));
			constructor = _tmp31_;
			_tmp32_ = constructor_sym;
			if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp32_, VALA_TYPE_CREATION_METHOD)) {
				ValaSourceReference* _tmp33_ = NULL;
				ValaSourceReference* _tmp34_ = NULL;
				ValaMethod* _tmp35_ = NULL;
				gchar* _tmp36_ = NULL;
				gchar* _tmp37_ = NULL;
				gchar* _tmp38_ = NULL;
				gchar* _tmp39_ = NULL;
				vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
				_tmp33_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
				_tmp34_ = _tmp33_;
				_tmp35_ = constructor;
				_tmp36_ = vala_symbol_get_full_name ((ValaSymbol*) _tmp35_);
				_tmp37_ = _tmp36_;
				_tmp38_ = g_strdup_printf ("`%s' is not a creation method", _tmp37_);
				_tmp39_ = _tmp38_;
				vala_report_error (_tmp34_, _tmp39_);
				_g_free0 (_tmp39_);
				_g_free0 (_tmp37_);
				result = FALSE;
				_vala_code_node_unref0 (constructor);
				_vala_iterable_unref0 (type_args);
				_vala_code_node_unref0 (type_sym);
				_vala_code_node_unref0 (constructor_sym);
				_vala_code_node_unref0 (type);
				return result;
			}
			_tmp40_ = constructor;
			vala_expression_set_symbol_reference ((ValaExpression*) self, (ValaSymbol*) _tmp40_);
			_tmp41_ = self->priv->_member_name;
			_tmp42_ = vala_member_access_get_inner (_tmp41_);
			_tmp43_ = _tmp42_;
			_tmp44_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp43_, VALA_TYPE_MEMBER_ACCESS) ? ((ValaMemberAccess*) _tmp43_) : NULL);
			ma = _tmp44_;
			_tmp45_ = ma;
			if (_tmp45_ != NULL) {
				ValaMemberAccess* _tmp46_ = NULL;
				ValaList* _tmp47_ = NULL;
				_tmp46_ = ma;
				_tmp47_ = vala_member_access_get_type_arguments (_tmp46_);
				_vala_iterable_unref0 (type_args);
				type_args = _tmp47_;
			}
			_vala_code_node_unref0 (ma);
			_vala_code_node_unref0 (constructor);
		}
		_tmp48_ = type_sym;
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp48_, VALA_TYPE_CLASS)) {
			ValaSymbol* _tmp49_ = NULL;
			ValaTypeSymbol* _tmp50_ = NULL;
			ValaTypeSymbol* _tmp51_ = NULL;
			gboolean _tmp52_ = FALSE;
			gboolean _tmp53_ = FALSE;
			_tmp49_ = type_sym;
			_tmp50_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp49_, VALA_TYPE_TYPESYMBOL, ValaTypeSymbol));
			_vala_code_node_unref0 (type);
			type = _tmp50_;
			_tmp51_ = type;
			_tmp52_ = vala_class_get_is_error_base (G_TYPE_CHECK_INSTANCE_CAST (_tmp51_, VALA_TYPE_CLASS, ValaClass));
			_tmp53_ = _tmp52_;
			if (_tmp53_) {
				ValaSourceReference* _tmp54_ = NULL;
				ValaSourceReference* _tmp55_ = NULL;
				ValaErrorType* _tmp56_ = NULL;
				ValaErrorType* _tmp57_ = NULL;
				_tmp54_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
				_tmp55_ = _tmp54_;
				_tmp56_ = vala_error_type_new (NULL, NULL, _tmp55_);
				_tmp57_ = _tmp56_;
				vala_object_creation_expression_set_type_reference (self, (ValaDataType*) _tmp57_);
				_vala_code_node_unref0 (_tmp57_);
			} else {
				ValaTypeSymbol* _tmp58_ = NULL;
				ValaObjectType* _tmp59_ = NULL;
				ValaObjectType* _tmp60_ = NULL;
				_tmp58_ = type;
				_tmp59_ = vala_object_type_new ((ValaObjectTypeSymbol*) G_TYPE_CHECK_INSTANCE_CAST (_tmp58_, VALA_TYPE_CLASS, ValaClass));
				_tmp60_ = _tmp59_;
				vala_object_creation_expression_set_type_reference (self, (ValaDataType*) _tmp60_);
				_vala_code_node_unref0 (_tmp60_);
			}
		} else {
			ValaSymbol* _tmp61_ = NULL;
			_tmp61_ = type_sym;
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp61_, VALA_TYPE_STRUCT)) {
				ValaSymbol* _tmp62_ = NULL;
				ValaTypeSymbol* _tmp63_ = NULL;
				ValaTypeSymbol* _tmp64_ = NULL;
				ValaStructValueType* _tmp65_ = NULL;
				ValaStructValueType* _tmp66_ = NULL;
				_tmp62_ = type_sym;
				_tmp63_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp62_, VALA_TYPE_TYPESYMBOL, ValaTypeSymbol));
				_vala_code_node_unref0 (type);
				type = _tmp63_;
				_tmp64_ = type;
				_tmp65_ = vala_struct_value_type_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp64_, VALA_TYPE_STRUCT, ValaStruct));
				_tmp66_ = _tmp65_;
				vala_object_creation_expression_set_type_reference (self, (ValaDataType*) _tmp66_);
				_vala_code_node_unref0 (_tmp66_);
			} else {
				ValaSymbol* _tmp67_ = NULL;
				_tmp67_ = type_sym;
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp67_, VALA_TYPE_ERROR_CODE)) {
					ValaSymbol* _tmp68_ = NULL;
					ValaSymbol* _tmp69_ = NULL;
					ValaSymbol* _tmp70_ = NULL;
					ValaSymbol* _tmp71_ = NULL;
					ValaSourceReference* _tmp72_ = NULL;
					ValaSourceReference* _tmp73_ = NULL;
					ValaErrorType* _tmp74_ = NULL;
					ValaErrorType* _tmp75_ = NULL;
					ValaSymbol* _tmp76_ = NULL;
					_tmp68_ = type_sym;
					_tmp69_ = vala_symbol_get_parent_symbol (_tmp68_);
					_tmp70_ = _tmp69_;
					_tmp71_ = type_sym;
					_tmp72_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
					_tmp73_ = _tmp72_;
					_tmp74_ = vala_error_type_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp70_, VALA_TYPE_ERROR_DOMAIN, ValaErrorDomain), G_TYPE_CHECK_INSTANCE_CAST (_tmp71_, VALA_TYPE_ERROR_CODE, ValaErrorCode), _tmp73_);
					_tmp75_ = _tmp74_;
					vala_object_creation_expression_set_type_reference (self, (ValaDataType*) _tmp75_);
					_vala_code_node_unref0 (_tmp75_);
					_tmp76_ = type_sym;
					vala_expression_set_symbol_reference ((ValaExpression*) self, _tmp76_);
				} else {
					ValaSourceReference* _tmp77_ = NULL;
					ValaSourceReference* _tmp78_ = NULL;
					ValaSymbol* _tmp79_ = NULL;
					gchar* _tmp80_ = NULL;
					gchar* _tmp81_ = NULL;
					gchar* _tmp82_ = NULL;
					gchar* _tmp83_ = NULL;
					vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
					_tmp77_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
					_tmp78_ = _tmp77_;
					_tmp79_ = type_sym;
					_tmp80_ = vala_symbol_get_full_name (_tmp79_);
					_tmp81_ = _tmp80_;
					_tmp82_ = g_strdup_printf ("`%s' is not a class, struct, or error code", _tmp81_);
					_tmp83_ = _tmp82_;
					vala_report_error (_tmp78_, _tmp83_);
					_g_free0 (_tmp83_);
					_g_free0 (_tmp81_);
					result = FALSE;
					_vala_iterable_unref0 (type_args);
					_vala_code_node_unref0 (type_sym);
					_vala_code_node_unref0 (constructor_sym);
					_vala_code_node_unref0 (type);
					return result;
				}
			}
		}
		{
			ValaList* _type_arg_list = NULL;
			ValaList* _tmp84_ = NULL;
			ValaList* _tmp85_ = NULL;
			gint _type_arg_size = 0;
			ValaList* _tmp86_ = NULL;
			gint _tmp87_ = 0;
			gint _tmp88_ = 0;
			gint _type_arg_index = 0;
			_tmp84_ = type_args;
			_tmp85_ = _vala_iterable_ref0 (_tmp84_);
			_type_arg_list = _tmp85_;
			_tmp86_ = _type_arg_list;
			_tmp87_ = vala_collection_get_size ((ValaCollection*) _tmp86_);
			_tmp88_ = _tmp87_;
			_type_arg_size = _tmp88_;
			_type_arg_index = -1;
			while (TRUE) {
				gint _tmp89_ = 0;
				gint _tmp90_ = 0;
				gint _tmp91_ = 0;
				ValaDataType* type_arg = NULL;
				ValaList* _tmp92_ = NULL;
				gint _tmp93_ = 0;
				gpointer _tmp94_ = NULL;
				ValaDataType* _tmp95_ = NULL;
				ValaDataType* _tmp96_ = NULL;
				ValaDataType* _tmp97_ = NULL;
				_tmp89_ = _type_arg_index;
				_type_arg_index = _tmp89_ + 1;
				_tmp90_ = _type_arg_index;
				_tmp91_ = _type_arg_size;
				if (!(_tmp90_ < _tmp91_)) {
					break;
				}
				_tmp92_ = _type_arg_list;
				_tmp93_ = _type_arg_index;
				_tmp94_ = vala_list_get (_tmp92_, _tmp93_);
				type_arg = (ValaDataType*) _tmp94_;
				_tmp95_ = vala_object_creation_expression_get_type_reference (self);
				_tmp96_ = _tmp95_;
				_tmp97_ = type_arg;
				vala_data_type_add_type_argument (_tmp96_, _tmp97_);
				_vala_code_node_unref0 (type_arg);
			}
			_vala_iterable_unref0 (_type_arg_list);
		}
		_vala_iterable_unref0 (type_args);
		_vala_code_node_unref0 (type_sym);
		_vala_code_node_unref0 (constructor_sym);
	} else {
		ValaDataType* _tmp98_ = NULL;
		ValaDataType* _tmp99_ = NULL;
		ValaTypeSymbol* _tmp100_ = NULL;
		ValaTypeSymbol* _tmp101_ = NULL;
		ValaTypeSymbol* _tmp102_ = NULL;
		_tmp98_ = vala_object_creation_expression_get_type_reference (self);
		_tmp99_ = _tmp98_;
		_tmp100_ = vala_data_type_get_data_type (_tmp99_);
		_tmp101_ = _tmp100_;
		_tmp102_ = _vala_code_node_ref0 (_tmp101_);
		_vala_code_node_unref0 (type);
		type = _tmp102_;
	}
	_tmp103_ = vala_object_creation_expression_get_type_reference (self);
	_tmp104_ = _tmp103_;
	_tmp105_ = vala_data_type_copy (_tmp104_);
	_tmp106_ = _tmp105_;
	vala_expression_set_value_type ((ValaExpression*) self, _tmp106_);
	_vala_code_node_unref0 (_tmp106_);
	_tmp107_ = vala_expression_get_value_type ((ValaExpression*) self);
	_tmp108_ = _tmp107_;
	vala_data_type_set_value_owned (_tmp108_, TRUE);
	may_throw = FALSE;
	_tmp109_ = vala_object_creation_expression_get_type_reference (self);
	_tmp110_ = _tmp109_;
	_tmp111_ = vala_data_type_get_type_arguments (_tmp110_);
	_tmp112_ = _tmp111_;
	_tmp113_ = vala_collection_get_size ((ValaCollection*) _tmp112_);
	_tmp114_ = _tmp113_;
	_tmp115_ = _tmp114_;
	_vala_iterable_unref0 (_tmp112_);
	given_num_type_args = _tmp115_;
	expected_num_type_args = 0;
	_tmp116_ = type;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp116_, VALA_TYPE_CLASS)) {
		ValaClass* cl = NULL;
		ValaTypeSymbol* _tmp117_ = NULL;
		ValaClass* _tmp118_ = NULL;
		ValaClass* _tmp119_ = NULL;
		ValaList* _tmp120_ = NULL;
		ValaList* _tmp121_ = NULL;
		gint _tmp122_ = 0;
		gint _tmp123_ = 0;
		gboolean _tmp124_ = FALSE;
		ValaClass* _tmp127_ = NULL;
		gboolean _tmp128_ = FALSE;
		gboolean _tmp129_ = FALSE;
		ValaSymbol* _tmp137_ = NULL;
		ValaSymbol* _tmp138_ = NULL;
		gboolean _tmp157_ = FALSE;
		ValaSymbol* _tmp158_ = NULL;
		ValaSymbol* _tmp159_ = NULL;
		_tmp117_ = type;
		_tmp118_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp117_, VALA_TYPE_CLASS, ValaClass));
		cl = _tmp118_;
		_tmp119_ = cl;
		_tmp120_ = vala_object_type_symbol_get_type_parameters ((ValaObjectTypeSymbol*) _tmp119_);
		_tmp121_ = _tmp120_;
		_tmp122_ = vala_collection_get_size ((ValaCollection*) _tmp121_);
		_tmp123_ = _tmp122_;
		expected_num_type_args = _tmp123_;
		_vala_iterable_unref0 (_tmp121_);
		_tmp124_ = self->priv->_struct_creation;
		if (_tmp124_) {
			ValaSourceReference* _tmp125_ = NULL;
			ValaSourceReference* _tmp126_ = NULL;
			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
			_tmp125_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
			_tmp126_ = _tmp125_;
			vala_report_error (_tmp126_, "syntax error, use `new' to create new objects");
			result = FALSE;
			_vala_code_node_unref0 (cl);
			_vala_code_node_unref0 (type);
			return result;
		}
		_tmp127_ = cl;
		_tmp128_ = vala_class_get_is_abstract (_tmp127_);
		_tmp129_ = _tmp128_;
		if (_tmp129_) {
			ValaSourceReference* _tmp130_ = NULL;
			ValaSourceReference* _tmp131_ = NULL;
			ValaClass* _tmp132_ = NULL;
			gchar* _tmp133_ = NULL;
			gchar* _tmp134_ = NULL;
			gchar* _tmp135_ = NULL;
			gchar* _tmp136_ = NULL;
			vala_expression_set_value_type ((ValaExpression*) self, NULL);
			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
			_tmp130_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
			_tmp131_ = _tmp130_;
			_tmp132_ = cl;
			_tmp133_ = vala_symbol_get_full_name ((ValaSymbol*) _tmp132_);
			_tmp134_ = _tmp133_;
			_tmp135_ = g_strdup_printf ("Can't create instance of abstract class `%s'", _tmp134_);
			_tmp136_ = _tmp135_;
			vala_report_error (_tmp131_, _tmp136_);
			_g_free0 (_tmp136_);
			_g_free0 (_tmp134_);
			result = FALSE;
			_vala_code_node_unref0 (cl);
			_vala_code_node_unref0 (type);
			return result;
		}
		_tmp137_ = vala_expression_get_symbol_reference ((ValaExpression*) self);
		_tmp138_ = _tmp137_;
		if (_tmp138_ == NULL) {
			ValaClass* _tmp139_ = NULL;
			ValaCreationMethod* _tmp140_ = NULL;
			ValaCreationMethod* _tmp141_ = NULL;
			ValaSymbol* _tmp142_ = NULL;
			ValaSymbol* _tmp143_ = NULL;
			ValaSymbol* _tmp151_ = NULL;
			ValaSymbol* _tmp152_ = NULL;
			ValaSymbol* _tmp153_ = NULL;
			ValaSymbol* _tmp154_ = NULL;
			ValaSourceReference* _tmp155_ = NULL;
			ValaSourceReference* _tmp156_ = NULL;
			_tmp139_ = cl;
			_tmp140_ = vala_class_get_default_construction_method (_tmp139_);
			_tmp141_ = _tmp140_;
			vala_expression_set_symbol_reference ((ValaExpression*) self, (ValaSymbol*) _tmp141_);
			_tmp142_ = vala_expression_get_symbol_reference ((ValaExpression*) self);
			_tmp143_ = _tmp142_;
			if (_tmp143_ == NULL) {
				ValaSourceReference* _tmp144_ = NULL;
				ValaSourceReference* _tmp145_ = NULL;
				ValaClass* _tmp146_ = NULL;
				gchar* _tmp147_ = NULL;
				gchar* _tmp148_ = NULL;
				gchar* _tmp149_ = NULL;
				gchar* _tmp150_ = NULL;
				vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
				_tmp144_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
				_tmp145_ = _tmp144_;
				_tmp146_ = cl;
				_tmp147_ = vala_symbol_get_full_name ((ValaSymbol*) _tmp146_);
				_tmp148_ = _tmp147_;
				_tmp149_ = g_strdup_printf ("`%s' does not have a default constructor", _tmp148_);
				_tmp150_ = _tmp149_;
				vala_report_error (_tmp145_, _tmp150_);
				_g_free0 (_tmp150_);
				_g_free0 (_tmp148_);
				result = FALSE;
				_vala_code_node_unref0 (cl);
				_vala_code_node_unref0 (type);
				return result;
			}
			_tmp151_ = vala_expression_get_symbol_reference ((ValaExpression*) self);
			_tmp152_ = _tmp151_;
			vala_symbol_set_used (_tmp152_, TRUE);
			_tmp153_ = vala_expression_get_symbol_reference ((ValaExpression*) self);
			_tmp154_ = _tmp153_;
			_tmp155_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
			_tmp156_ = _tmp155_;
			vala_symbol_check_deprecated (_tmp154_, _tmp156_);
		}
		_tmp158_ = vala_expression_get_symbol_reference ((ValaExpression*) self);
		_tmp159_ = _tmp158_;
		if (_tmp159_ != NULL) {
			ValaSymbol* _tmp160_ = NULL;
			ValaSymbol* _tmp161_ = NULL;
			ValaSymbolAccessibility _tmp162_ = 0;
			ValaSymbolAccessibility _tmp163_ = 0;
			_tmp160_ = vala_expression_get_symbol_reference ((ValaExpression*) self);
			_tmp161_ = _tmp160_;
			_tmp162_ = vala_symbol_get_access (_tmp161_);
			_tmp163_ = _tmp162_;
			_tmp157_ = _tmp163_ == VALA_SYMBOL_ACCESSIBILITY_PRIVATE;
		} else {
			_tmp157_ = FALSE;
		}
		if (_tmp157_) {
			gboolean in_target_type = FALSE;
			gboolean _tmp178_ = FALSE;
			in_target_type = FALSE;
			{
				ValaSymbol* this_symbol = NULL;
				ValaCodeContext* _tmp164_ = NULL;
				ValaSemanticAnalyzer* _tmp165_ = NULL;
				ValaSemanticAnalyzer* _tmp166_ = NULL;
				ValaSymbol* _tmp167_ = NULL;
				ValaSymbol* _tmp168_ = NULL;
				ValaSymbol* _tmp169_ = NULL;
				_tmp164_ = context;
				_tmp165_ = vala_code_context_get_analyzer (_tmp164_);
				_tmp166_ = _tmp165_;
				_tmp167_ = vala_semantic_analyzer_get_current_symbol (_tmp166_);
				_tmp168_ = _tmp167_;
				_tmp169_ = _vala_code_node_ref0 (_tmp168_);
				this_symbol = _tmp169_;
				{
					gboolean _tmp170_ = FALSE;
					_tmp170_ = TRUE;
					while (TRUE) {
						ValaSymbol* _tmp175_ = NULL;
						ValaSymbol* _tmp176_ = NULL;
						ValaClass* _tmp177_ = NULL;
						if (!_tmp170_) {
							ValaSymbol* _tmp171_ = NULL;
							ValaSymbol* _tmp172_ = NULL;
							ValaSymbol* _tmp173_ = NULL;
							ValaSymbol* _tmp174_ = NULL;
							_tmp171_ = this_symbol;
							_tmp172_ = vala_symbol_get_parent_symbol (_tmp171_);
							_tmp173_ = _tmp172_;
							_tmp174_ = _vala_code_node_ref0 (_tmp173_);
							_vala_code_node_unref0 (this_symbol);
							this_symbol = _tmp174_;
						}
						_tmp170_ = FALSE;
						_tmp175_ = this_symbol;
						if (!(_tmp175_ != NULL)) {
							break;
						}
						_tmp176_ = this_symbol;
						_tmp177_ = cl;
						if (_tmp176_ == G_TYPE_CHECK_INSTANCE_CAST (_tmp177_, VALA_TYPE_SYMBOL, ValaSymbol)) {
							in_target_type = TRUE;
							break;
						}
					}
				}
				_vala_code_node_unref0 (this_symbol);
			}
			_tmp178_ = in_target_type;
			if (!_tmp178_) {
				ValaSourceReference* _tmp179_ = NULL;
				ValaSourceReference* _tmp180_ = NULL;
				ValaSymbol* _tmp181_ = NULL;
				ValaSymbol* _tmp182_ = NULL;
				gchar* _tmp183_ = NULL;
				gchar* _tmp184_ = NULL;
				gchar* _tmp185_ = NULL;
				gchar* _tmp186_ = NULL;
				vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
				_tmp179_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
				_tmp180_ = _tmp179_;
				_tmp181_ = vala_expression_get_symbol_reference ((ValaExpression*) self);
				_tmp182_ = _tmp181_;
				_tmp183_ = vala_symbol_get_full_name (_tmp182_);
				_tmp184_ = _tmp183_;
				_tmp185_ = g_strdup_printf ("Access to private member `%s' denied", _tmp184_);
				_tmp186_ = _tmp185_;
				vala_report_error (_tmp180_, _tmp186_);
				_g_free0 (_tmp186_);
				_g_free0 (_tmp184_);
				result = FALSE;
				_vala_code_node_unref0 (cl);
				_vala_code_node_unref0 (type);
				return result;
			}
		}
		while (TRUE) {
			ValaClass* _tmp187_ = NULL;
			ValaClass* _tmp188_ = NULL;
			gchar* _tmp189_ = NULL;
			gchar* _tmp190_ = NULL;
			gboolean _tmp191_ = FALSE;
			ValaClass* _tmp194_ = NULL;
			ValaClass* _tmp195_ = NULL;
			ValaClass* _tmp196_ = NULL;
			ValaClass* _tmp197_ = NULL;
			_tmp187_ = cl;
			if (!(_tmp187_ != NULL)) {
				break;
			}
			_tmp188_ = cl;
			_tmp189_ = vala_code_node_get_attribute_string ((ValaCodeNode*) _tmp188_, "CCode", "ref_sink_function", NULL);
			_tmp190_ = _tmp189_;
			_tmp191_ = _tmp190_ != NULL;
			_g_free0 (_tmp190_);
			if (_tmp191_) {
				ValaDataType* _tmp192_ = NULL;
				ValaDataType* _tmp193_ = NULL;
				_tmp192_ = vala_expression_get_value_type ((ValaExpression*) self);
				_tmp193_ = _tmp192_;
				vala_data_type_set_floating_reference (_tmp193_, TRUE);
				break;
			}
			_tmp194_ = cl;
			_tmp195_ = vala_class_get_base_class (_tmp194_);
			_tmp196_ = _tmp195_;
			_tmp197_ = _vala_code_node_ref0 (_tmp196_);
			_vala_code_node_unref0 (cl);
			cl = _tmp197_;
		}
		_vala_code_node_unref0 (cl);
	} else {
		ValaTypeSymbol* _tmp198_ = NULL;
		_tmp198_ = type;
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp198_, VALA_TYPE_STRUCT)) {
			ValaStruct* st = NULL;
			ValaTypeSymbol* _tmp199_ = NULL;
			ValaStruct* _tmp200_ = NULL;
			ValaStruct* _tmp201_ = NULL;
			ValaList* _tmp202_ = NULL;
			ValaList* _tmp203_ = NULL;
			gint _tmp204_ = 0;
			gint _tmp205_ = 0;
			gboolean _tmp206_ = FALSE;
			gboolean _tmp207_ = FALSE;
			ValaSymbol* _tmp213_ = NULL;
			ValaSymbol* _tmp214_ = NULL;
			gboolean _tmp218_ = FALSE;
			gboolean _tmp219_ = FALSE;
			ValaStruct* _tmp220_ = NULL;
			gboolean _tmp221_ = FALSE;
			_tmp199_ = type;
			_tmp200_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp199_, VALA_TYPE_STRUCT, ValaStruct));
			st = _tmp200_;
			_tmp201_ = st;
			_tmp202_ = vala_struct_get_type_parameters (_tmp201_);
			_tmp203_ = _tmp202_;
			_tmp204_ = vala_collection_get_size ((ValaCollection*) _tmp203_);
			_tmp205_ = _tmp204_;
			expected_num_type_args = _tmp205_;
			_vala_iterable_unref0 (_tmp203_);
			_tmp207_ = self->priv->_struct_creation;
			if (!_tmp207_) {
				ValaCodeContext* _tmp208_ = NULL;
				gboolean _tmp209_ = FALSE;
				gboolean _tmp210_ = FALSE;
				_tmp208_ = context;
				_tmp209_ = vala_code_context_get_deprecated (_tmp208_);
				_tmp210_ = _tmp209_;
				_tmp206_ = !_tmp210_;
			} else {
				_tmp206_ = FALSE;
			}
			if (_tmp206_) {
				ValaSourceReference* _tmp211_ = NULL;
				ValaSourceReference* _tmp212_ = NULL;
				_tmp211_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
				_tmp212_ = _tmp211_;
				vala_report_warning (_tmp212_, "deprecated syntax, don't use `new' to initialize structs");
			}
			_tmp213_ = vala_expression_get_symbol_reference ((ValaExpression*) self);
			_tmp214_ = _tmp213_;
			if (_tmp214_ == NULL) {
				ValaStruct* _tmp215_ = NULL;
				ValaMethod* _tmp216_ = NULL;
				ValaMethod* _tmp217_ = NULL;
				_tmp215_ = st;
				_tmp216_ = vala_struct_get_default_construction_method (_tmp215_);
				_tmp217_ = _tmp216_;
				vala_expression_set_symbol_reference ((ValaExpression*) self, (ValaSymbol*) _tmp217_);
			}
			_tmp220_ = st;
			_tmp221_ = vala_struct_is_simple_type (_tmp220_);
			if (_tmp221_) {
				ValaSymbol* _tmp222_ = NULL;
				ValaSymbol* _tmp223_ = NULL;
				_tmp222_ = vala_expression_get_symbol_reference ((ValaExpression*) self);
				_tmp223_ = _tmp222_;
				_tmp219_ = _tmp223_ == NULL;
			} else {
				_tmp219_ = FALSE;
			}
			if (_tmp219_) {
				ValaList* _tmp224_ = NULL;
				gint _tmp225_ = 0;
				gint _tmp226_ = 0;
				_tmp224_ = self->priv->object_initializer;
				_tmp225_ = vala_collection_get_size ((ValaCollection*) _tmp224_);
				_tmp226_ = _tmp225_;
				_tmp218_ = _tmp226_ == 0;
			} else {
				_tmp218_ = FALSE;
			}
			if (_tmp218_) {
				ValaSourceReference* _tmp227_ = NULL;
				ValaSourceReference* _tmp228_ = NULL;
				ValaStruct* _tmp229_ = NULL;
				gchar* _tmp230_ = NULL;
				gchar* _tmp231_ = NULL;
				gchar* _tmp232_ = NULL;
				gchar* _tmp233_ = NULL;
				vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
				_tmp227_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
				_tmp228_ = _tmp227_;
				_tmp229_ = st;
				_tmp230_ = vala_symbol_get_full_name ((ValaSymbol*) _tmp229_);
				_tmp231_ = _tmp230_;
				_tmp232_ = g_strdup_printf ("`%s' does not have a default constructor", _tmp231_);
				_tmp233_ = _tmp232_;
				vala_report_error (_tmp228_, _tmp233_);
				_g_free0 (_tmp233_);
				_g_free0 (_tmp231_);
				result = FALSE;
				_vala_code_node_unref0 (st);
				_vala_code_node_unref0 (type);
				return result;
			}
			_vala_code_node_unref0 (st);
		}
	}
	_tmp234_ = expected_num_type_args;
	_tmp235_ = given_num_type_args;
	if (_tmp234_ > _tmp235_) {
		ValaSourceReference* _tmp236_ = NULL;
		ValaSourceReference* _tmp237_ = NULL;
		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
		_tmp236_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
		_tmp237_ = _tmp236_;
		vala_report_error (_tmp237_, "too few type arguments");
		result = FALSE;
		_vala_code_node_unref0 (type);
		return result;
	} else {
		gint _tmp238_ = 0;
		gint _tmp239_ = 0;
		_tmp238_ = expected_num_type_args;
		_tmp239_ = given_num_type_args;
		if (_tmp238_ < _tmp239_) {
			ValaSourceReference* _tmp240_ = NULL;
			ValaSourceReference* _tmp241_ = NULL;
			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
			_tmp240_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
			_tmp241_ = _tmp240_;
			vala_report_error (_tmp241_, "too many type arguments");
			result = FALSE;
			_vala_code_node_unref0 (type);
			return result;
		}
	}
	_tmp243_ = vala_expression_get_symbol_reference ((ValaExpression*) self);
	_tmp244_ = _tmp243_;
	if (_tmp244_ == NULL) {
		ValaList* _tmp245_ = NULL;
		ValaList* _tmp246_ = NULL;
		gint _tmp247_ = 0;
		gint _tmp248_ = 0;
		_tmp245_ = vala_object_creation_expression_get_argument_list (self);
		_tmp246_ = _tmp245_;
		_tmp247_ = vala_collection_get_size ((ValaCollection*) _tmp246_);
		_tmp248_ = _tmp247_;
		_tmp242_ = _tmp248_ != 0;
		_vala_iterable_unref0 (_tmp246_);
	} else {
		_tmp242_ = FALSE;
	}
	if (_tmp242_) {
		ValaSourceReference* _tmp249_ = NULL;
		ValaSourceReference* _tmp250_ = NULL;
		ValaTypeSymbol* _tmp251_ = NULL;
		gchar* _tmp252_ = NULL;
		gchar* _tmp253_ = NULL;
		gchar* _tmp254_ = NULL;
		gchar* _tmp255_ = NULL;
		vala_expression_set_value_type ((ValaExpression*) self, NULL);
		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
		_tmp249_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
		_tmp250_ = _tmp249_;
		_tmp251_ = type;
		_tmp252_ = vala_symbol_get_full_name ((ValaSymbol*) _tmp251_);
		_tmp253_ = _tmp252_;
		_tmp254_ = g_strdup_printf ("No arguments allowed when constructing type `%s'", _tmp253_);
		_tmp255_ = _tmp254_;
		vala_report_error (_tmp250_, _tmp255_);
		_g_free0 (_tmp255_);
		_g_free0 (_tmp253_);
		result = FALSE;
		_vala_code_node_unref0 (type);
		return result;
	}
	_tmp256_ = vala_expression_get_symbol_reference ((ValaExpression*) self);
	_tmp257_ = _tmp256_;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp257_, VALA_TYPE_METHOD)) {
		ValaMethod* m = NULL;
		ValaSymbol* _tmp258_ = NULL;
		ValaSymbol* _tmp259_ = NULL;
		ValaMethod* _tmp260_ = NULL;
		gboolean _tmp261_ = FALSE;
		ValaList* args = NULL;
		ValaList* _tmp289_ = NULL;
		ValaIterator* arg_it = NULL;
		ValaList* _tmp290_ = NULL;
		ValaIterator* _tmp291_ = NULL;
		ValaCodeContext* _tmp335_ = NULL;
		ValaSemanticAnalyzer* _tmp336_ = NULL;
		ValaSemanticAnalyzer* _tmp337_ = NULL;
		ValaMethod* _tmp338_ = NULL;
		ValaMethodType* _tmp339_ = NULL;
		ValaMethodType* _tmp340_ = NULL;
		ValaMethod* _tmp341_ = NULL;
		ValaList* _tmp342_ = NULL;
		ValaList* _tmp343_ = NULL;
		ValaList* _tmp344_ = NULL;
		_tmp258_ = vala_expression_get_symbol_reference ((ValaExpression*) self);
		_tmp259_ = _tmp258_;
		_tmp260_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp259_, VALA_TYPE_METHOD, ValaMethod));
		m = _tmp260_;
		_tmp261_ = self->priv->_is_yield_expression;
		if (_tmp261_) {
			ValaMethod* _tmp262_ = NULL;
			gboolean _tmp263_ = FALSE;
			gboolean _tmp264_ = FALSE;
			gboolean _tmp267_ = FALSE;
			ValaCodeContext* _tmp268_ = NULL;
			ValaSemanticAnalyzer* _tmp269_ = NULL;
			ValaSemanticAnalyzer* _tmp270_ = NULL;
			ValaMethod* _tmp271_ = NULL;
			ValaMethod* _tmp272_ = NULL;
			ValaCodeContext* _tmp282_ = NULL;
			ValaSemanticAnalyzer* _tmp283_ = NULL;
			ValaSemanticAnalyzer* _tmp284_ = NULL;
			ValaMethod* _tmp285_ = NULL;
			ValaMethod* _tmp286_ = NULL;
			gint _tmp287_ = 0;
			gint _tmp288_ = 0;
			_tmp262_ = m;
			_tmp263_ = vala_method_get_coroutine (_tmp262_);
			_tmp264_ = _tmp263_;
			if (!_tmp264_) {
				ValaSourceReference* _tmp265_ = NULL;
				ValaSourceReference* _tmp266_ = NULL;
				vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
				_tmp265_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
				_tmp266_ = _tmp265_;
				vala_report_error (_tmp266_, "yield expression requires async method");
			}
			_tmp268_ = context;
			_tmp269_ = vala_code_context_get_analyzer (_tmp268_);
			_tmp270_ = _tmp269_;
			_tmp271_ = vala_semantic_analyzer_get_current_method (_tmp270_);
			_tmp272_ = _tmp271_;
			if (_tmp272_ == NULL) {
				_tmp267_ = TRUE;
			} else {
				ValaCodeContext* _tmp273_ = NULL;
				ValaSemanticAnalyzer* _tmp274_ = NULL;
				ValaSemanticAnalyzer* _tmp275_ = NULL;
				ValaMethod* _tmp276_ = NULL;
				ValaMethod* _tmp277_ = NULL;
				gboolean _tmp278_ = FALSE;
				gboolean _tmp279_ = FALSE;
				_tmp273_ = context;
				_tmp274_ = vala_code_context_get_analyzer (_tmp273_);
				_tmp275_ = _tmp274_;
				_tmp276_ = vala_semantic_analyzer_get_current_method (_tmp275_);
				_tmp277_ = _tmp276_;
				_tmp278_ = vala_method_get_coroutine (_tmp277_);
				_tmp279_ = _tmp278_;
				_tmp267_ = !_tmp279_;
			}
			if (_tmp267_) {
				ValaSourceReference* _tmp280_ = NULL;
				ValaSourceReference* _tmp281_ = NULL;
				vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
				_tmp280_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
				_tmp281_ = _tmp280_;
				vala_report_error (_tmp281_, "yield expression not available outside async method");
			}
			_tmp282_ = context;
			_tmp283_ = vala_code_context_get_analyzer (_tmp282_);
			_tmp284_ = _tmp283_;
			_tmp285_ = vala_semantic_analyzer_get_current_method (_tmp284_);
			_tmp286_ = _tmp285_;
			_tmp287_ = vala_method_get_yield_count (_tmp286_);
			_tmp288_ = _tmp287_;
			vala_method_set_yield_count (_tmp286_, _tmp288_ + 1);
		}
		_tmp289_ = vala_object_creation_expression_get_argument_list (self);
		args = _tmp289_;
		_tmp290_ = args;
		_tmp291_ = vala_iterable_iterator ((ValaIterable*) _tmp290_);
		arg_it = _tmp291_;
		{
			ValaList* _param_list = NULL;
			ValaMethod* _tmp292_ = NULL;
			ValaList* _tmp293_ = NULL;
			gint _param_size = 0;
			ValaList* _tmp294_ = NULL;
			gint _tmp295_ = 0;
			gint _tmp296_ = 0;
			gint _param_index = 0;
			_tmp292_ = m;
			_tmp293_ = vala_method_get_parameters (_tmp292_);
			_param_list = _tmp293_;
			_tmp294_ = _param_list;
			_tmp295_ = vala_collection_get_size ((ValaCollection*) _tmp294_);
			_tmp296_ = _tmp295_;
			_param_size = _tmp296_;
			_param_index = -1;
			while (TRUE) {
				gint _tmp297_ = 0;
				gint _tmp298_ = 0;
				gint _tmp299_ = 0;
				ValaParameter* param = NULL;
				ValaList* _tmp300_ = NULL;
				gint _tmp301_ = 0;
				gpointer _tmp302_ = NULL;
				ValaParameter* _tmp303_ = NULL;
				gboolean _tmp304_ = FALSE;
				gboolean _tmp305_ = FALSE;
				ValaIterator* _tmp306_ = NULL;
				gboolean _tmp307_ = FALSE;
				_tmp297_ = _param_index;
				_param_index = _tmp297_ + 1;
				_tmp298_ = _param_index;
				_tmp299_ = _param_size;
				if (!(_tmp298_ < _tmp299_)) {
					break;
				}
				_tmp300_ = _param_list;
				_tmp301_ = _param_index;
				_tmp302_ = vala_list_get (_tmp300_, _tmp301_);
				param = (ValaParameter*) _tmp302_;
				_tmp303_ = param;
				_tmp304_ = vala_parameter_get_ellipsis (_tmp303_);
				_tmp305_ = _tmp304_;
				if (_tmp305_) {
					_vala_code_node_unref0 (param);
					break;
				}
				_tmp306_ = arg_it;
				_tmp307_ = vala_iterator_next (_tmp306_);
				if (_tmp307_) {
					ValaExpression* arg = NULL;
					ValaIterator* _tmp308_ = NULL;
					gpointer _tmp309_ = NULL;
					ValaExpression* _tmp310_ = NULL;
					ValaParameter* _tmp311_ = NULL;
					ValaDataType* _tmp312_ = NULL;
					ValaDataType* _tmp313_ = NULL;
					ValaExpression* _tmp314_ = NULL;
					ValaExpression* _tmp315_ = NULL;
					ValaDataType* _tmp316_ = NULL;
					ValaDataType* _tmp317_ = NULL;
					ValaDataType* _tmp318_ = NULL;
					ValaDataType* _tmp319_ = NULL;
					ValaDataType* _tmp320_ = NULL;
					ValaDataType* _tmp321_ = NULL;
					_tmp308_ = arg_it;
					_tmp309_ = vala_iterator_get (_tmp308_);
					arg = (ValaExpression*) _tmp309_;
					_tmp310_ = arg;
					_tmp311_ = param;
					_tmp312_ = vala_variable_get_variable_type ((ValaVariable*) _tmp311_);
					_tmp313_ = _tmp312_;
					vala_expression_set_formal_target_type (_tmp310_, _tmp313_);
					_tmp314_ = arg;
					_tmp315_ = arg;
					_tmp316_ = vala_expression_get_formal_target_type (_tmp315_);
					_tmp317_ = _tmp316_;
					_tmp318_ = vala_expression_get_value_type ((ValaExpression*) self);
					_tmp319_ = _tmp318_;
					_tmp320_ = vala_data_type_get_actual_type (_tmp317_, _tmp319_, NULL, (ValaCodeNode*) self);
					_tmp321_ = _tmp320_;
					vala_expression_set_target_type (_tmp314_, _tmp321_);
					_vala_code_node_unref0 (_tmp321_);
					_vala_code_node_unref0 (arg);
				}
				_vala_code_node_unref0 (param);
			}
			_vala_iterable_unref0 (_param_list);
		}
		{
			ValaList* _arg_list = NULL;
			ValaList* _tmp322_ = NULL;
			ValaList* _tmp323_ = NULL;
			gint _arg_size = 0;
			ValaList* _tmp324_ = NULL;
			gint _tmp325_ = 0;
			gint _tmp326_ = 0;
			gint _arg_index = 0;
			_tmp322_ = args;
			_tmp323_ = _vala_iterable_ref0 (_tmp322_);
			_arg_list = _tmp323_;
			_tmp324_ = _arg_list;
			_tmp325_ = vala_collection_get_size ((ValaCollection*) _tmp324_);
			_tmp326_ = _tmp325_;
			_arg_size = _tmp326_;
			_arg_index = -1;
			while (TRUE) {
				gint _tmp327_ = 0;
				gint _tmp328_ = 0;
				gint _tmp329_ = 0;
				ValaExpression* arg = NULL;
				ValaList* _tmp330_ = NULL;
				gint _tmp331_ = 0;
				gpointer _tmp332_ = NULL;
				ValaExpression* _tmp333_ = NULL;
				ValaCodeContext* _tmp334_ = NULL;
				_tmp327_ = _arg_index;
				_arg_index = _tmp327_ + 1;
				_tmp328_ = _arg_index;
				_tmp329_ = _arg_size;
				if (!(_tmp328_ < _tmp329_)) {
					break;
				}
				_tmp330_ = _arg_list;
				_tmp331_ = _arg_index;
				_tmp332_ = vala_list_get (_tmp330_, _tmp331_);
				arg = (ValaExpression*) _tmp332_;
				_tmp333_ = arg;
				_tmp334_ = context;
				vala_code_node_check ((ValaCodeNode*) _tmp333_, _tmp334_);
				_vala_code_node_unref0 (arg);
			}
			_vala_iterable_unref0 (_arg_list);
		}
		_tmp335_ = context;
		_tmp336_ = vala_code_context_get_analyzer (_tmp335_);
		_tmp337_ = _tmp336_;
		_tmp338_ = m;
		_tmp339_ = vala_method_type_new (_tmp338_);
		_tmp340_ = _tmp339_;
		_tmp341_ = m;
		_tmp342_ = vala_method_get_parameters (_tmp341_);
		_tmp343_ = _tmp342_;
		_tmp344_ = args;
		vala_semantic_analyzer_check_arguments (_tmp337_, (ValaExpression*) self, (ValaDataType*) _tmp340_, _tmp343_, _tmp344_);
		_vala_iterable_unref0 (_tmp343_);
		_vala_code_node_unref0 (_tmp340_);
		{
			ValaList* _error_type_list = NULL;
			ValaMethod* _tmp345_ = NULL;
			ValaList* _tmp346_ = NULL;
			gint _error_type_size = 0;
			ValaList* _tmp347_ = NULL;
			gint _tmp348_ = 0;
			gint _tmp349_ = 0;
			gint _error_type_index = 0;
			_tmp345_ = m;
			_tmp346_ = vala_code_node_get_error_types ((ValaCodeNode*) _tmp345_);
			_error_type_list = _tmp346_;
			_tmp347_ = _error_type_list;
			_tmp348_ = vala_collection_get_size ((ValaCollection*) _tmp347_);
			_tmp349_ = _tmp348_;
			_error_type_size = _tmp349_;
			_error_type_index = -1;
			while (TRUE) {
				gint _tmp350_ = 0;
				gint _tmp351_ = 0;
				gint _tmp352_ = 0;
				ValaDataType* error_type = NULL;
				ValaList* _tmp353_ = NULL;
				gint _tmp354_ = 0;
				gpointer _tmp355_ = NULL;
				ValaDataType* call_error_type = NULL;
				ValaDataType* _tmp356_ = NULL;
				ValaDataType* _tmp357_ = NULL;
				ValaDataType* _tmp358_ = NULL;
				ValaSourceReference* _tmp359_ = NULL;
				ValaSourceReference* _tmp360_ = NULL;
				ValaDataType* _tmp361_ = NULL;
				_tmp350_ = _error_type_index;
				_error_type_index = _tmp350_ + 1;
				_tmp351_ = _error_type_index;
				_tmp352_ = _error_type_size;
				if (!(_tmp351_ < _tmp352_)) {
					break;
				}
				_tmp353_ = _error_type_list;
				_tmp354_ = _error_type_index;
				_tmp355_ = vala_list_get (_tmp353_, _tmp354_);
				error_type = (ValaDataType*) _tmp355_;
				may_throw = TRUE;
				_tmp356_ = error_type;
				_tmp357_ = vala_data_type_copy (_tmp356_);
				call_error_type = _tmp357_;
				_tmp358_ = call_error_type;
				_tmp359_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
				_tmp360_ = _tmp359_;
				vala_code_node_set_source_reference ((ValaCodeNode*) _tmp358_, _tmp360_);
				_tmp361_ = call_error_type;
				vala_code_node_add_error_type ((ValaCodeNode*) self, _tmp361_);
				_vala_code_node_unref0 (call_error_type);
				_vala_code_node_unref0 (error_type);
			}
			_vala_iterable_unref0 (_error_type_list);
		}
		_vala_iterator_unref0 (arg_it);
		_vala_iterable_unref0 (args);
		_vala_code_node_unref0 (m);
	} else {
		ValaDataType* _tmp362_ = NULL;
		ValaDataType* _tmp363_ = NULL;
		_tmp362_ = vala_object_creation_expression_get_type_reference (self);
		_tmp363_ = _tmp362_;
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp363_, VALA_TYPE_ERROR_TYPE)) {
			ValaDataType* _tmp364_ = NULL;
			ValaDataType* _tmp365_ = NULL;
			ValaMemberAccess* _tmp369_ = NULL;
			ValaList* _tmp398_ = NULL;
			ValaList* _tmp399_ = NULL;
			gint _tmp400_ = 0;
			gint _tmp401_ = 0;
			gboolean _tmp402_ = FALSE;
			_tmp364_ = vala_object_creation_expression_get_type_reference (self);
			_tmp365_ = _tmp364_;
			if (_tmp365_ != NULL) {
				ValaDataType* _tmp366_ = NULL;
				ValaDataType* _tmp367_ = NULL;
				ValaCodeContext* _tmp368_ = NULL;
				_tmp366_ = vala_object_creation_expression_get_type_reference (self);
				_tmp367_ = _tmp366_;
				_tmp368_ = context;
				vala_code_node_check ((ValaCodeNode*) _tmp367_, _tmp368_);
			}
			_tmp369_ = self->priv->_member_name;
			if (_tmp369_ != NULL) {
				ValaMemberAccess* _tmp370_ = NULL;
				ValaCodeContext* _tmp371_ = NULL;
				_tmp370_ = self->priv->_member_name;
				_tmp371_ = context;
				vala_code_node_check ((ValaCodeNode*) _tmp370_, _tmp371_);
			}
			{
				ValaList* _arg_list = NULL;
				ValaList* _tmp372_ = NULL;
				ValaList* _tmp373_ = NULL;
				gint _arg_size = 0;
				ValaList* _tmp374_ = NULL;
				gint _tmp375_ = 0;
				gint _tmp376_ = 0;
				gint _arg_index = 0;
				_tmp372_ = self->priv->argument_list;
				_tmp373_ = _vala_iterable_ref0 (_tmp372_);
				_arg_list = _tmp373_;
				_tmp374_ = _arg_list;
				_tmp375_ = vala_collection_get_size ((ValaCollection*) _tmp374_);
				_tmp376_ = _tmp375_;
				_arg_size = _tmp376_;
				_arg_index = -1;
				while (TRUE) {
					gint _tmp377_ = 0;
					gint _tmp378_ = 0;
					gint _tmp379_ = 0;
					ValaExpression* arg = NULL;
					ValaList* _tmp380_ = NULL;
					gint _tmp381_ = 0;
					gpointer _tmp382_ = NULL;
					ValaExpression* _tmp383_ = NULL;
					ValaCodeContext* _tmp384_ = NULL;
					_tmp377_ = _arg_index;
					_arg_index = _tmp377_ + 1;
					_tmp378_ = _arg_index;
					_tmp379_ = _arg_size;
					if (!(_tmp378_ < _tmp379_)) {
						break;
					}
					_tmp380_ = _arg_list;
					_tmp381_ = _arg_index;
					_tmp382_ = vala_list_get (_tmp380_, _tmp381_);
					arg = (ValaExpression*) _tmp382_;
					_tmp383_ = arg;
					_tmp384_ = context;
					vala_code_node_check ((ValaCodeNode*) _tmp383_, _tmp384_);
					_vala_code_node_unref0 (arg);
				}
				_vala_iterable_unref0 (_arg_list);
			}
			{
				ValaList* _init_list = NULL;
				ValaList* _tmp385_ = NULL;
				ValaList* _tmp386_ = NULL;
				gint _init_size = 0;
				ValaList* _tmp387_ = NULL;
				gint _tmp388_ = 0;
				gint _tmp389_ = 0;
				gint _init_index = 0;
				_tmp385_ = self->priv->object_initializer;
				_tmp386_ = _vala_iterable_ref0 (_tmp385_);
				_init_list = _tmp386_;
				_tmp387_ = _init_list;
				_tmp388_ = vala_collection_get_size ((ValaCollection*) _tmp387_);
				_tmp389_ = _tmp388_;
				_init_size = _tmp389_;
				_init_index = -1;
				while (TRUE) {
					gint _tmp390_ = 0;
					gint _tmp391_ = 0;
					gint _tmp392_ = 0;
					ValaMemberInitializer* init = NULL;
					ValaList* _tmp393_ = NULL;
					gint _tmp394_ = 0;
					gpointer _tmp395_ = NULL;
					ValaMemberInitializer* _tmp396_ = NULL;
					ValaCodeContext* _tmp397_ = NULL;
					_tmp390_ = _init_index;
					_init_index = _tmp390_ + 1;
					_tmp391_ = _init_index;
					_tmp392_ = _init_size;
					if (!(_tmp391_ < _tmp392_)) {
						break;
					}
					_tmp393_ = _init_list;
					_tmp394_ = _init_index;
					_tmp395_ = vala_list_get (_tmp393_, _tmp394_);
					init = (ValaMemberInitializer*) _tmp395_;
					_tmp396_ = init;
					_tmp397_ = context;
					vala_code_node_check ((ValaCodeNode*) _tmp396_, _tmp397_);
					_vala_code_node_unref0 (init);
				}
				_vala_iterable_unref0 (_init_list);
			}
			_tmp398_ = vala_object_creation_expression_get_argument_list (self);
			_tmp399_ = _tmp398_;
			_tmp400_ = vala_collection_get_size ((ValaCollection*) _tmp399_);
			_tmp401_ = _tmp400_;
			_tmp402_ = _tmp401_ == 0;
			_vala_iterable_unref0 (_tmp399_);
			if (_tmp402_) {
				ValaSourceReference* _tmp403_ = NULL;
				ValaSourceReference* _tmp404_ = NULL;
				vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
				_tmp403_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
				_tmp404_ = _tmp403_;
				vala_report_error (_tmp404_, "Too few arguments, errors need at least 1 argument");
			} else {
				ValaIterator* arg_it = NULL;
				ValaList* _tmp405_ = NULL;
				ValaList* _tmp406_ = NULL;
				ValaIterator* _tmp407_ = NULL;
				ValaIterator* _tmp408_ = NULL;
				ValaIterator* _tmp409_ = NULL;
				ValaExpression* ex = NULL;
				ValaIterator* _tmp410_ = NULL;
				gpointer _tmp411_ = NULL;
				gboolean _tmp412_ = FALSE;
				ValaExpression* _tmp413_ = NULL;
				ValaDataType* _tmp414_ = NULL;
				ValaDataType* _tmp415_ = NULL;
				ValaStringLiteral* format_literal = NULL;
				ValaExpression* _tmp426_ = NULL;
				ValaStringLiteral* _tmp427_ = NULL;
				ValaStringLiteral* _tmp428_ = NULL;
				ValaList* _tmp439_ = NULL;
				ValaList* _tmp440_ = NULL;
				ValaIterator* _tmp441_ = NULL;
				ValaIterator* _tmp442_ = NULL;
				ValaCodeContext* _tmp443_ = NULL;
				ValaSemanticAnalyzer* _tmp444_ = NULL;
				ValaSemanticAnalyzer* _tmp445_ = NULL;
				ValaIterator* _tmp446_ = NULL;
				ValaSourceReference* _tmp447_ = NULL;
				ValaSourceReference* _tmp448_ = NULL;
				gboolean _tmp449_ = FALSE;
				_tmp405_ = vala_object_creation_expression_get_argument_list (self);
				_tmp406_ = _tmp405_;
				_tmp407_ = vala_iterable_iterator ((ValaIterable*) _tmp406_);
				_tmp408_ = _tmp407_;
				_vala_iterable_unref0 (_tmp406_);
				arg_it = _tmp408_;
				_tmp409_ = arg_it;
				vala_iterator_next (_tmp409_);
				_tmp410_ = arg_it;
				_tmp411_ = vala_iterator_get (_tmp410_);
				ex = (ValaExpression*) _tmp411_;
				_tmp413_ = ex;
				_tmp414_ = vala_expression_get_value_type (_tmp413_);
				_tmp415_ = _tmp414_;
				if (_tmp415_ == NULL) {
					_tmp412_ = TRUE;
				} else {
					ValaExpression* _tmp416_ = NULL;
					ValaDataType* _tmp417_ = NULL;
					ValaDataType* _tmp418_ = NULL;
					ValaCodeContext* _tmp419_ = NULL;
					ValaSemanticAnalyzer* _tmp420_ = NULL;
					ValaSemanticAnalyzer* _tmp421_ = NULL;
					ValaDataType* _tmp422_ = NULL;
					gboolean _tmp423_ = FALSE;
					_tmp416_ = ex;
					_tmp417_ = vala_expression_get_value_type (_tmp416_);
					_tmp418_ = _tmp417_;
					_tmp419_ = context;
					_tmp420_ = vala_code_context_get_analyzer (_tmp419_);
					_tmp421_ = _tmp420_;
					_tmp422_ = _tmp421_->string_type;
					_tmp423_ = vala_data_type_compatible (_tmp418_, _tmp422_);
					_tmp412_ = !_tmp423_;
				}
				if (_tmp412_) {
					ValaSourceReference* _tmp424_ = NULL;
					ValaSourceReference* _tmp425_ = NULL;
					vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
					_tmp424_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
					_tmp425_ = _tmp424_;
					vala_report_error (_tmp425_, "Invalid type for argument 1");
				}
				_tmp426_ = ex;
				_tmp427_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp426_, VALA_TYPE_STRING_LITERAL) ? ((ValaStringLiteral*) _tmp426_) : NULL);
				format_literal = _tmp427_;
				_tmp428_ = format_literal;
				if (_tmp428_ != NULL) {
					gchar* format = NULL;
					ValaStringLiteral* _tmp429_ = NULL;
					gchar* _tmp430_ = NULL;
					ValaCodeContext* _tmp431_ = NULL;
					ValaSemanticAnalyzer* _tmp432_ = NULL;
					ValaSemanticAnalyzer* _tmp433_ = NULL;
					const gchar* _tmp434_ = NULL;
					ValaIterator* _tmp435_ = NULL;
					ValaSourceReference* _tmp436_ = NULL;
					ValaSourceReference* _tmp437_ = NULL;
					gboolean _tmp438_ = FALSE;
					_tmp429_ = format_literal;
					_tmp430_ = vala_string_literal_eval (_tmp429_);
					format = _tmp430_;
					_tmp431_ = context;
					_tmp432_ = vala_code_context_get_analyzer (_tmp431_);
					_tmp433_ = _tmp432_;
					_tmp434_ = format;
					_tmp435_ = arg_it;
					_tmp436_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
					_tmp437_ = _tmp436_;
					_tmp438_ = vala_semantic_analyzer_check_print_format (_tmp433_, _tmp434_, _tmp435_, _tmp437_);
					if (!_tmp438_) {
						vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
						result = FALSE;
						_g_free0 (format);
						_vala_code_node_unref0 (format_literal);
						_vala_code_node_unref0 (ex);
						_vala_iterator_unref0 (arg_it);
						_vala_code_node_unref0 (type);
						return result;
					}
					_g_free0 (format);
				}
				_tmp439_ = vala_object_creation_expression_get_argument_list (self);
				_tmp440_ = _tmp439_;
				_tmp441_ = vala_iterable_iterator ((ValaIterable*) _tmp440_);
				_vala_iterator_unref0 (arg_it);
				arg_it = _tmp441_;
				_vala_iterable_unref0 (_tmp440_);
				_tmp442_ = arg_it;
				vala_iterator_next (_tmp442_);
				_tmp443_ = context;
				_tmp444_ = vala_code_context_get_analyzer (_tmp443_);
				_tmp445_ = _tmp444_;
				_tmp446_ = arg_it;
				_tmp447_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
				_tmp448_ = _tmp447_;
				_tmp449_ = vala_semantic_analyzer_check_variadic_arguments (_tmp445_, _tmp446_, 1, _tmp448_);
				if (!_tmp449_) {
					vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
					result = FALSE;
					_vala_code_node_unref0 (format_literal);
					_vala_code_node_unref0 (ex);
					_vala_iterator_unref0 (arg_it);
					_vala_code_node_unref0 (type);
					return result;
				}
				_vala_code_node_unref0 (format_literal);
				_vala_code_node_unref0 (ex);
				_vala_iterator_unref0 (arg_it);
			}
		}
	}
	{
		ValaList* _init_list = NULL;
		ValaList* _tmp450_ = NULL;
		gint _init_size = 0;
		ValaList* _tmp451_ = NULL;
		gint _tmp452_ = 0;
		gint _tmp453_ = 0;
		gint _init_index = 0;
		_tmp450_ = vala_object_creation_expression_get_object_initializer (self);
		_init_list = _tmp450_;
		_tmp451_ = _init_list;
		_tmp452_ = vala_collection_get_size ((ValaCollection*) _tmp451_);
		_tmp453_ = _tmp452_;
		_init_size = _tmp453_;
		_init_index = -1;
		while (TRUE) {
			gint _tmp454_ = 0;
			gint _tmp455_ = 0;
			gint _tmp456_ = 0;
			ValaMemberInitializer* init = NULL;
			ValaList* _tmp457_ = NULL;
			gint _tmp458_ = 0;
			gpointer _tmp459_ = NULL;
			ValaCodeContext* _tmp460_ = NULL;
			ValaSemanticAnalyzer* _tmp461_ = NULL;
			ValaSemanticAnalyzer* _tmp462_ = NULL;
			ValaMemberInitializer* _tmp463_ = NULL;
			ValaDataType* _tmp464_ = NULL;
			ValaDataType* _tmp465_ = NULL;
			_tmp454_ = _init_index;
			_init_index = _tmp454_ + 1;
			_tmp455_ = _init_index;
			_tmp456_ = _init_size;
			if (!(_tmp455_ < _tmp456_)) {
				break;
			}
			_tmp457_ = _init_list;
			_tmp458_ = _init_index;
			_tmp459_ = vala_list_get (_tmp457_, _tmp458_);
			init = (ValaMemberInitializer*) _tmp459_;
			_tmp460_ = context;
			_tmp461_ = vala_code_context_get_analyzer (_tmp460_);
			_tmp462_ = _tmp461_;
			_tmp463_ = init;
			_tmp464_ = vala_object_creation_expression_get_type_reference (self);
			_tmp465_ = _tmp464_;
			vala_semantic_analyzer_visit_member_initializer (_tmp462_, _tmp463_, _tmp465_);
			_vala_code_node_unref0 (init);
		}
		_vala_iterable_unref0 (_init_list);
	}
	_tmp466_ = may_throw;
	if (_tmp466_) {
		gboolean _tmp467_ = FALSE;
		ValaCodeNode* _tmp468_ = NULL;
		ValaCodeNode* _tmp469_ = NULL;
		_tmp468_ = vala_code_node_get_parent_node ((ValaCodeNode*) self);
		_tmp469_ = _tmp468_;
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp469_, VALA_TYPE_LOCAL_VARIABLE)) {
			_tmp467_ = TRUE;
		} else {
			ValaCodeNode* _tmp470_ = NULL;
			ValaCodeNode* _tmp471_ = NULL;
			_tmp470_ = vala_code_node_get_parent_node ((ValaCodeNode*) self);
			_tmp471_ = _tmp470_;
			_tmp467_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp471_, VALA_TYPE_EXPRESSION_STATEMENT);
		}
		if (_tmp467_) {
		} else {
			ValaCodeContext* _tmp472_ = NULL;
			ValaSemanticAnalyzer* _tmp473_ = NULL;
			ValaSemanticAnalyzer* _tmp474_ = NULL;
			ValaSymbol* _tmp475_ = NULL;
			ValaSymbol* _tmp476_ = NULL;
			_tmp472_ = context;
			_tmp473_ = vala_code_context_get_analyzer (_tmp472_);
			_tmp474_ = _tmp473_;
			_tmp475_ = vala_semantic_analyzer_get_current_symbol (_tmp474_);
			_tmp476_ = _tmp475_;
			if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp476_, VALA_TYPE_BLOCK)) {
				ValaSourceReference* _tmp477_ = NULL;
				ValaSourceReference* _tmp478_ = NULL;
				_tmp477_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
				_tmp478_ = _tmp477_;
				vala_report_error (_tmp478_, "Field initializers must not throw errors");
			} else {
				ValaCodeNode* old_parent_node = NULL;
				ValaCodeNode* _tmp479_ = NULL;
				ValaCodeNode* _tmp480_ = NULL;
				ValaCodeNode* _tmp481_ = NULL;
				ValaLocalVariable* local = NULL;
				ValaDataType* _tmp482_ = NULL;
				ValaDataType* _tmp483_ = NULL;
				ValaDataType* _tmp484_ = NULL;
				ValaDataType* _tmp485_ = NULL;
				gchar* _tmp486_ = NULL;
				gchar* _tmp487_ = NULL;
				ValaSourceReference* _tmp488_ = NULL;
				ValaSourceReference* _tmp489_ = NULL;
				ValaLocalVariable* _tmp490_ = NULL;
				ValaLocalVariable* _tmp491_ = NULL;
				ValaDeclarationStatement* decl = NULL;
				ValaLocalVariable* _tmp492_ = NULL;
				ValaSourceReference* _tmp493_ = NULL;
				ValaSourceReference* _tmp494_ = NULL;
				ValaDeclarationStatement* _tmp495_ = NULL;
				ValaCodeContext* _tmp496_ = NULL;
				ValaSemanticAnalyzer* _tmp497_ = NULL;
				ValaSemanticAnalyzer* _tmp498_ = NULL;
				ValaBlock* _tmp499_ = NULL;
				ValaDeclarationStatement* _tmp500_ = NULL;
				ValaExpression* temp_access = NULL;
				ValaLocalVariable* _tmp501_ = NULL;
				ValaDataType* _tmp502_ = NULL;
				ValaDataType* _tmp503_ = NULL;
				ValaExpression* _tmp504_ = NULL;
				ValaLocalVariable* _tmp505_ = NULL;
				ValaDeclarationStatement* _tmp506_ = NULL;
				ValaCodeContext* _tmp507_ = NULL;
				ValaBlock* block = NULL;
				ValaCodeContext* _tmp508_ = NULL;
				ValaSemanticAnalyzer* _tmp509_ = NULL;
				ValaSemanticAnalyzer* _tmp510_ = NULL;
				ValaSymbol* _tmp511_ = NULL;
				ValaSymbol* _tmp512_ = NULL;
				ValaBlock* _tmp513_ = NULL;
				ValaBlock* _tmp514_ = NULL;
				ValaLocalVariable* _tmp515_ = NULL;
				ValaCodeContext* _tmp516_ = NULL;
				ValaSemanticAnalyzer* _tmp517_ = NULL;
				ValaSemanticAnalyzer* _tmp518_ = NULL;
				ValaBlock* _tmp519_ = NULL;
				ValaLocalVariable* _tmp520_ = NULL;
				ValaCodeNode* _tmp521_ = NULL;
				ValaExpression* _tmp522_ = NULL;
				ValaExpression* _tmp523_ = NULL;
				ValaCodeContext* _tmp524_ = NULL;
				_tmp479_ = vala_code_node_get_parent_node ((ValaCodeNode*) self);
				_tmp480_ = _tmp479_;
				_tmp481_ = _vala_code_node_ref0 (_tmp480_);
				old_parent_node = _tmp481_;
				_tmp482_ = vala_expression_get_value_type ((ValaExpression*) self);
				_tmp483_ = _tmp482_;
				_tmp484_ = vala_data_type_copy (_tmp483_);
				_tmp485_ = _tmp484_;
				_tmp486_ = vala_code_node_get_temp_name ();
				_tmp487_ = _tmp486_;
				_tmp488_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
				_tmp489_ = _tmp488_;
				_tmp490_ = vala_local_variable_new (_tmp485_, _tmp487_, NULL, _tmp489_);
				_tmp491_ = _tmp490_;
				_g_free0 (_tmp487_);
				_vala_code_node_unref0 (_tmp485_);
				local = _tmp491_;
				_tmp492_ = local;
				_tmp493_ = vala_code_node_get_source_reference ((ValaCodeNode*) self);
				_tmp494_ = _tmp493_;
				_tmp495_ = vala_declaration_statement_new ((ValaSymbol*) _tmp492_, _tmp494_);
				decl = _tmp495_;
				_tmp496_ = context;
				_tmp497_ = vala_code_context_get_analyzer (_tmp496_);
				_tmp498_ = _tmp497_;
				_tmp499_ = _tmp498_->insert_block;
				_tmp500_ = decl;
				vala_expression_insert_statement ((ValaExpression*) self, _tmp499_, (ValaStatement*) _tmp500_);
				_tmp501_ = local;
				_tmp502_ = vala_expression_get_target_type ((ValaExpression*) self);
				_tmp503_ = _tmp502_;
				_tmp504_ = vala_semantic_analyzer_create_temp_access (_tmp501_, _tmp503_);
				temp_access = _tmp504_;
				_tmp505_ = local;
				vala_variable_set_initializer ((ValaVariable*) _tmp505_, (ValaExpression*) self);
				_tmp506_ = decl;
				_tmp507_ = context;
				vala_code_node_check ((ValaCodeNode*) _tmp506_, _tmp507_);
				_tmp508_ = context;
				_tmp509_ = vala_code_context_get_analyzer (_tmp508_);
				_tmp510_ = _tmp509_;
				_tmp511_ = vala_semantic_analyzer_get_current_symbol (_tmp510_);
				_tmp512_ = _tmp511_;
				_tmp513_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp512_, VALA_TYPE_BLOCK, ValaBlock));
				block = _tmp513_;
				_tmp514_ = block;
				_tmp515_ = local;
				vala_block_remove_local_variable (_tmp514_, _tmp515_);
				_tmp516_ = context;
				_tmp517_ = vala_code_context_get_analyzer (_tmp516_);
				_tmp518_ = _tmp517_;
				_tmp519_ = _tmp518_->insert_block;
				_tmp520_ = local;
				vala_block_add_local_variable (_tmp519_, _tmp520_);
				_tmp521_ = old_parent_node;
				_tmp522_ = temp_access;
				vala_code_node_replace_expression (_tmp521_, (ValaExpression*) self, _tmp522_);
				_tmp523_ = temp_access;
				_tmp524_ = context;
				vala_code_node_check ((ValaCodeNode*) _tmp523_, _tmp524_);
				_vala_code_node_unref0 (block);
				_vala_code_node_unref0 (temp_access);
				_vala_code_node_unref0 (decl);
				_vala_code_node_unref0 (local);
				_vala_code_node_unref0 (old_parent_node);
			}
		}
	}
	_tmp525_ = vala_code_node_get_error ((ValaCodeNode*) self);
	_tmp526_ = _tmp525_;
	result = !_tmp526_;
	_vala_code_node_unref0 (type);
	return result;
}


static void vala_object_creation_expression_real_emit (ValaCodeNode* base, ValaCodeGenerator* codegen) {
	ValaObjectCreationExpression * self;
	ValaCodeGenerator* _tmp26_ = NULL;
	ValaCodeGenerator* _tmp27_ = NULL;
	self = (ValaObjectCreationExpression*) base;
	g_return_if_fail (codegen != NULL);
	{
		ValaList* _arg_list = NULL;
		ValaList* _tmp0_ = NULL;
		ValaList* _tmp1_ = NULL;
		gint _arg_size = 0;
		ValaList* _tmp2_ = NULL;
		gint _tmp3_ = 0;
		gint _tmp4_ = 0;
		gint _arg_index = 0;
		_tmp0_ = self->priv->argument_list;
		_tmp1_ = _vala_iterable_ref0 (_tmp0_);
		_arg_list = _tmp1_;
		_tmp2_ = _arg_list;
		_tmp3_ = vala_collection_get_size ((ValaCollection*) _tmp2_);
		_tmp4_ = _tmp3_;
		_arg_size = _tmp4_;
		_arg_index = -1;
		while (TRUE) {
			gint _tmp5_ = 0;
			gint _tmp6_ = 0;
			gint _tmp7_ = 0;
			ValaExpression* arg = NULL;
			ValaList* _tmp8_ = NULL;
			gint _tmp9_ = 0;
			gpointer _tmp10_ = NULL;
			ValaExpression* _tmp11_ = NULL;
			ValaCodeGenerator* _tmp12_ = NULL;
			_tmp5_ = _arg_index;
			_arg_index = _tmp5_ + 1;
			_tmp6_ = _arg_index;
			_tmp7_ = _arg_size;
			if (!(_tmp6_ < _tmp7_)) {
				break;
			}
			_tmp8_ = _arg_list;
			_tmp9_ = _arg_index;
			_tmp10_ = vala_list_get (_tmp8_, _tmp9_);
			arg = (ValaExpression*) _tmp10_;
			_tmp11_ = arg;
			_tmp12_ = codegen;
			vala_code_node_emit ((ValaCodeNode*) _tmp11_, _tmp12_);
			_vala_code_node_unref0 (arg);
		}
		_vala_iterable_unref0 (_arg_list);
	}
	{
		ValaList* _init_list = NULL;
		ValaList* _tmp13_ = NULL;
		ValaList* _tmp14_ = NULL;
		gint _init_size = 0;
		ValaList* _tmp15_ = NULL;
		gint _tmp16_ = 0;
		gint _tmp17_ = 0;
		gint _init_index = 0;
		_tmp13_ = self->priv->object_initializer;
		_tmp14_ = _vala_iterable_ref0 (_tmp13_);
		_init_list = _tmp14_;
		_tmp15_ = _init_list;
		_tmp16_ = vala_collection_get_size ((ValaCollection*) _tmp15_);
		_tmp17_ = _tmp16_;
		_init_size = _tmp17_;
		_init_index = -1;
		while (TRUE) {
			gint _tmp18_ = 0;
			gint _tmp19_ = 0;
			gint _tmp20_ = 0;
			ValaMemberInitializer* init = NULL;
			ValaList* _tmp21_ = NULL;
			gint _tmp22_ = 0;
			gpointer _tmp23_ = NULL;
			ValaMemberInitializer* _tmp24_ = NULL;
			ValaCodeGenerator* _tmp25_ = NULL;
			_tmp18_ = _init_index;
			_init_index = _tmp18_ + 1;
			_tmp19_ = _init_index;
			_tmp20_ = _init_size;
			if (!(_tmp19_ < _tmp20_)) {
				break;
			}
			_tmp21_ = _init_list;
			_tmp22_ = _init_index;
			_tmp23_ = vala_list_get (_tmp21_, _tmp22_);
			init = (ValaMemberInitializer*) _tmp23_;
			_tmp24_ = init;
			_tmp25_ = codegen;
			vala_code_node_emit ((ValaCodeNode*) _tmp24_, _tmp25_);
			_vala_code_node_unref0 (init);
		}
		_vala_iterable_unref0 (_init_list);
	}
	_tmp26_ = codegen;
	vala_code_visitor_visit_object_creation_expression ((ValaCodeVisitor*) _tmp26_, self);
	_tmp27_ = codegen;
	vala_code_visitor_visit_expression ((ValaCodeVisitor*) _tmp27_, (ValaExpression*) self);
}


static void vala_object_creation_expression_real_get_defined_variables (ValaCodeNode* base, ValaCollection* collection) {
	ValaObjectCreationExpression * self;
	self = (ValaObjectCreationExpression*) base;
	g_return_if_fail (collection != NULL);
	{
		ValaList* _arg_list = NULL;
		ValaList* _tmp0_ = NULL;
		ValaList* _tmp1_ = NULL;
		gint _arg_size = 0;
		ValaList* _tmp2_ = NULL;
		gint _tmp3_ = 0;
		gint _tmp4_ = 0;
		gint _arg_index = 0;
		_tmp0_ = self->priv->argument_list;
		_tmp1_ = _vala_iterable_ref0 (_tmp0_);
		_arg_list = _tmp1_;
		_tmp2_ = _arg_list;
		_tmp3_ = vala_collection_get_size ((ValaCollection*) _tmp2_);
		_tmp4_ = _tmp3_;
		_arg_size = _tmp4_;
		_arg_index = -1;
		while (TRUE) {
			gint _tmp5_ = 0;
			gint _tmp6_ = 0;
			gint _tmp7_ = 0;
			ValaExpression* arg = NULL;
			ValaList* _tmp8_ = NULL;
			gint _tmp9_ = 0;
			gpointer _tmp10_ = NULL;
			ValaExpression* _tmp11_ = NULL;
			ValaCollection* _tmp12_ = NULL;
			_tmp5_ = _arg_index;
			_arg_index = _tmp5_ + 1;
			_tmp6_ = _arg_index;
			_tmp7_ = _arg_size;
			if (!(_tmp6_ < _tmp7_)) {
				break;
			}
			_tmp8_ = _arg_list;
			_tmp9_ = _arg_index;
			_tmp10_ = vala_list_get (_tmp8_, _tmp9_);
			arg = (ValaExpression*) _tmp10_;
			_tmp11_ = arg;
			_tmp12_ = collection;
			vala_code_node_get_defined_variables ((ValaCodeNode*) _tmp11_, _tmp12_);
			_vala_code_node_unref0 (arg);
		}
		_vala_iterable_unref0 (_arg_list);
	}
}


static void vala_object_creation_expression_real_get_used_variables (ValaCodeNode* base, ValaCollection* collection) {
	ValaObjectCreationExpression * self;
	self = (ValaObjectCreationExpression*) base;
	g_return_if_fail (collection != NULL);
	{
		ValaList* _arg_list = NULL;
		ValaList* _tmp0_ = NULL;
		ValaList* _tmp1_ = NULL;
		gint _arg_size = 0;
		ValaList* _tmp2_ = NULL;
		gint _tmp3_ = 0;
		gint _tmp4_ = 0;
		gint _arg_index = 0;
		_tmp0_ = self->priv->argument_list;
		_tmp1_ = _vala_iterable_ref0 (_tmp0_);
		_arg_list = _tmp1_;
		_tmp2_ = _arg_list;
		_tmp3_ = vala_collection_get_size ((ValaCollection*) _tmp2_);
		_tmp4_ = _tmp3_;
		_arg_size = _tmp4_;
		_arg_index = -1;
		while (TRUE) {
			gint _tmp5_ = 0;
			gint _tmp6_ = 0;
			gint _tmp7_ = 0;
			ValaExpression* arg = NULL;
			ValaList* _tmp8_ = NULL;
			gint _tmp9_ = 0;
			gpointer _tmp10_ = NULL;
			ValaExpression* _tmp11_ = NULL;
			ValaCollection* _tmp12_ = NULL;
			_tmp5_ = _arg_index;
			_arg_index = _tmp5_ + 1;
			_tmp6_ = _arg_index;
			_tmp7_ = _arg_size;
			if (!(_tmp6_ < _tmp7_)) {
				break;
			}
			_tmp8_ = _arg_list;
			_tmp9_ = _arg_index;
			_tmp10_ = vala_list_get (_tmp8_, _tmp9_);
			arg = (ValaExpression*) _tmp10_;
			_tmp11_ = arg;
			_tmp12_ = collection;
			vala_code_node_get_used_variables ((ValaCodeNode*) _tmp11_, _tmp12_);
			_vala_code_node_unref0 (arg);
		}
		_vala_iterable_unref0 (_arg_list);
	}
	{
		ValaList* _init_list = NULL;
		ValaList* _tmp13_ = NULL;
		ValaList* _tmp14_ = NULL;
		gint _init_size = 0;
		ValaList* _tmp15_ = NULL;
		gint _tmp16_ = 0;
		gint _tmp17_ = 0;
		gint _init_index = 0;
		_tmp13_ = self->priv->object_initializer;
		_tmp14_ = _vala_iterable_ref0 (_tmp13_);
		_init_list = _tmp14_;
		_tmp15_ = _init_list;
		_tmp16_ = vala_collection_get_size ((ValaCollection*) _tmp15_);
		_tmp17_ = _tmp16_;
		_init_size = _tmp17_;
		_init_index = -1;
		while (TRUE) {
			gint _tmp18_ = 0;
			gint _tmp19_ = 0;
			gint _tmp20_ = 0;
			ValaMemberInitializer* init = NULL;
			ValaList* _tmp21_ = NULL;
			gint _tmp22_ = 0;
			gpointer _tmp23_ = NULL;
			ValaMemberInitializer* _tmp24_ = NULL;
			ValaCollection* _tmp25_ = NULL;
			_tmp18_ = _init_index;
			_init_index = _tmp18_ + 1;
			_tmp19_ = _init_index;
			_tmp20_ = _init_size;
			if (!(_tmp19_ < _tmp20_)) {
				break;
			}
			_tmp21_ = _init_list;
			_tmp22_ = _init_index;
			_tmp23_ = vala_list_get (_tmp21_, _tmp22_);
			init = (ValaMemberInitializer*) _tmp23_;
			_tmp24_ = init;
			_tmp25_ = collection;
			vala_code_node_get_used_variables ((ValaCodeNode*) _tmp24_, _tmp25_);
			_vala_code_node_unref0 (init);
		}
		_vala_iterable_unref0 (_init_list);
	}
}


ValaDataType* vala_object_creation_expression_get_type_reference (ValaObjectCreationExpression* self) {
	ValaDataType* result;
	ValaDataType* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_data_type;
	result = _tmp0_;
	return result;
}


void vala_object_creation_expression_set_type_reference (ValaObjectCreationExpression* self, ValaDataType* value) {
	ValaDataType* _tmp0_ = NULL;
	ValaDataType* _tmp1_ = NULL;
	ValaDataType* _tmp2_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = _vala_code_node_ref0 (_tmp0_);
	_vala_code_node_unref0 (self->priv->_data_type);
	self->priv->_data_type = _tmp1_;
	_tmp2_ = self->priv->_data_type;
	vala_code_node_set_parent_node ((ValaCodeNode*) _tmp2_, (ValaCodeNode*) self);
}


ValaMemberAccess* vala_object_creation_expression_get_member_name (ValaObjectCreationExpression* self) {
	ValaMemberAccess* result;
	ValaMemberAccess* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_member_name;
	result = _tmp0_;
	return result;
}


void vala_object_creation_expression_set_member_name (ValaObjectCreationExpression* self, ValaMemberAccess* value) {
	ValaMemberAccess* _tmp0_ = NULL;
	ValaMemberAccess* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = _vala_code_node_ref0 (_tmp0_);
	_vala_code_node_unref0 (self->priv->_member_name);
	self->priv->_member_name = _tmp1_;
}


gboolean vala_object_creation_expression_get_is_yield_expression (ValaObjectCreationExpression* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->priv->_is_yield_expression;
	result = _tmp0_;
	return result;
}


void vala_object_creation_expression_set_is_yield_expression (ValaObjectCreationExpression* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	self->priv->_is_yield_expression = _tmp0_;
}


gboolean vala_object_creation_expression_get_struct_creation (ValaObjectCreationExpression* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->priv->_struct_creation;
	result = _tmp0_;
	return result;
}


void vala_object_creation_expression_set_struct_creation (ValaObjectCreationExpression* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	self->priv->_struct_creation = _tmp0_;
}


static void vala_object_creation_expression_class_init (ValaObjectCreationExpressionClass * klass) {
	vala_object_creation_expression_parent_class = g_type_class_peek_parent (klass);
	((ValaCodeNodeClass *) klass)->finalize = vala_object_creation_expression_finalize;
	g_type_class_add_private (klass, sizeof (ValaObjectCreationExpressionPrivate));
	((ValaCodeNodeClass *) klass)->accept = vala_object_creation_expression_real_accept;
	((ValaCodeNodeClass *) klass)->accept_children = vala_object_creation_expression_real_accept_children;
	((ValaCodeNodeClass *) klass)->replace_expression = vala_object_creation_expression_real_replace_expression;
	((ValaExpressionClass *) klass)->is_pure = vala_object_creation_expression_real_is_pure;
	((ValaCodeNodeClass *) klass)->replace_type = vala_object_creation_expression_real_replace_type;
	((ValaCodeNodeClass *) klass)->check = vala_object_creation_expression_real_check;
	((ValaCodeNodeClass *) klass)->emit = vala_object_creation_expression_real_emit;
	((ValaCodeNodeClass *) klass)->get_defined_variables = vala_object_creation_expression_real_get_defined_variables;
	((ValaCodeNodeClass *) klass)->get_used_variables = vala_object_creation_expression_real_get_used_variables;
}


static void vala_object_creation_expression_instance_init (ValaObjectCreationExpression * self) {
	GEqualFunc _tmp0_ = NULL;
	ValaArrayList* _tmp1_ = NULL;
	GEqualFunc _tmp2_ = NULL;
	ValaArrayList* _tmp3_ = NULL;
	self->priv = VALA_OBJECT_CREATION_EXPRESSION_GET_PRIVATE (self);
	_tmp0_ = g_direct_equal;
	_tmp1_ = vala_array_list_new (VALA_TYPE_EXPRESSION, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, _tmp0_);
	self->priv->argument_list = (ValaList*) _tmp1_;
	_tmp2_ = g_direct_equal;
	_tmp3_ = vala_array_list_new (VALA_TYPE_MEMBER_INITIALIZER, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, _tmp2_);
	self->priv->object_initializer = (ValaList*) _tmp3_;
}


static void vala_object_creation_expression_finalize (ValaCodeNode* obj) {
	ValaObjectCreationExpression * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, VALA_TYPE_OBJECT_CREATION_EXPRESSION, ValaObjectCreationExpression);
	_vala_code_node_unref0 (self->priv->_member_name);
	_vala_iterable_unref0 (self->priv->argument_list);
	_vala_iterable_unref0 (self->priv->object_initializer);
	_vala_code_node_unref0 (self->priv->_data_type);
	VALA_CODE_NODE_CLASS (vala_object_creation_expression_parent_class)->finalize (obj);
}


/**
 * Represents an object creation expression in the source code.
 */
GType vala_object_creation_expression_get_type (void) {
	static volatile gsize vala_object_creation_expression_type_id__volatile = 0;
	if (g_once_init_enter (&vala_object_creation_expression_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaObjectCreationExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_object_creation_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaObjectCreationExpression), 0, (GInstanceInitFunc) vala_object_creation_expression_instance_init, NULL };
		GType vala_object_creation_expression_type_id;
		vala_object_creation_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaObjectCreationExpression", &g_define_type_info, 0);
		g_once_init_leave (&vala_object_creation_expression_type_id__volatile, vala_object_creation_expression_type_id);
	}
	return vala_object_creation_expression_type_id__volatile;
}



